# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/integration/hugging_face_integration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/qwak/integration/hugging_face_integration.proto\x12\x1bqwak.integration.management\"\xa4\x01\n\x16HuggingFaceIntegration\x12\x81\x01\n/hugging_face_api_token_system_secret_descriptor\x18\x01 \x01(\x0b\x32\x46.qwak.integration.management.HuggingFaceApiTokenSystemSecretDescriptorH\x00\x42\x06\n\x04\x61uth\"\x8e\x01\n\x1aHuggingFaceIntegrationSpec\x12h\n\"hugging_face_api_token_auth_config\x18\x01 \x01(\x0b\x32:.qwak.integration.management.HuggingFaceApiTokenAuthConfigH\x00\x42\x06\n\x04\x61uth\"\x8d\x01\n\x19HuggingFaceValidationSpec\x12h\n\"hugging_face_api_token_auth_config\x18\x01 \x01(\x0b\x32:.qwak.integration.management.HuggingFaceApiTokenAuthConfigH\x00\x42\x06\n\x04\x61uth\"2\n\x1dHuggingFaceApiTokenAuthConfig\x12\x11\n\tapi_token\x18\x01 \x01(\t\"^\n)HuggingFaceApiTokenSystemSecretDescriptor\x12\x13\n\x0bsecret_name\x18\x01 \x01(\t\x12\x1c\n\x14\x61pi_token_secret_key\x18\x02 \x01(\t\"\x1f\n\x1dHuggingFaceIntegrationOptionsBH\n&com.qwak.ai.management.integration.apiP\x01Z\x1cqwak/integration;integrationb\x06proto3')



_HUGGINGFACEINTEGRATION = DESCRIPTOR.message_types_by_name['HuggingFaceIntegration']
_HUGGINGFACEINTEGRATIONSPEC = DESCRIPTOR.message_types_by_name['HuggingFaceIntegrationSpec']
_HUGGINGFACEVALIDATIONSPEC = DESCRIPTOR.message_types_by_name['HuggingFaceValidationSpec']
_HUGGINGFACEAPITOKENAUTHCONFIG = DESCRIPTOR.message_types_by_name['HuggingFaceApiTokenAuthConfig']
_HUGGINGFACEAPITOKENSYSTEMSECRETDESCRIPTOR = DESCRIPTOR.message_types_by_name['HuggingFaceApiTokenSystemSecretDescriptor']
_HUGGINGFACEINTEGRATIONOPTIONS = DESCRIPTOR.message_types_by_name['HuggingFaceIntegrationOptions']
HuggingFaceIntegration = _reflection.GeneratedProtocolMessageType('HuggingFaceIntegration', (_message.Message,), {
  'DESCRIPTOR' : _HUGGINGFACEINTEGRATION,
  '__module__' : 'qwak.integration.hugging_face_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.HuggingFaceIntegration)
  })
_sym_db.RegisterMessage(HuggingFaceIntegration)

HuggingFaceIntegrationSpec = _reflection.GeneratedProtocolMessageType('HuggingFaceIntegrationSpec', (_message.Message,), {
  'DESCRIPTOR' : _HUGGINGFACEINTEGRATIONSPEC,
  '__module__' : 'qwak.integration.hugging_face_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.HuggingFaceIntegrationSpec)
  })
_sym_db.RegisterMessage(HuggingFaceIntegrationSpec)

HuggingFaceValidationSpec = _reflection.GeneratedProtocolMessageType('HuggingFaceValidationSpec', (_message.Message,), {
  'DESCRIPTOR' : _HUGGINGFACEVALIDATIONSPEC,
  '__module__' : 'qwak.integration.hugging_face_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.HuggingFaceValidationSpec)
  })
_sym_db.RegisterMessage(HuggingFaceValidationSpec)

HuggingFaceApiTokenAuthConfig = _reflection.GeneratedProtocolMessageType('HuggingFaceApiTokenAuthConfig', (_message.Message,), {
  'DESCRIPTOR' : _HUGGINGFACEAPITOKENAUTHCONFIG,
  '__module__' : 'qwak.integration.hugging_face_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.HuggingFaceApiTokenAuthConfig)
  })
_sym_db.RegisterMessage(HuggingFaceApiTokenAuthConfig)

HuggingFaceApiTokenSystemSecretDescriptor = _reflection.GeneratedProtocolMessageType('HuggingFaceApiTokenSystemSecretDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _HUGGINGFACEAPITOKENSYSTEMSECRETDESCRIPTOR,
  '__module__' : 'qwak.integration.hugging_face_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.HuggingFaceApiTokenSystemSecretDescriptor)
  })
_sym_db.RegisterMessage(HuggingFaceApiTokenSystemSecretDescriptor)

HuggingFaceIntegrationOptions = _reflection.GeneratedProtocolMessageType('HuggingFaceIntegrationOptions', (_message.Message,), {
  'DESCRIPTOR' : _HUGGINGFACEINTEGRATIONOPTIONS,
  '__module__' : 'qwak.integration.hugging_face_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.HuggingFaceIntegrationOptions)
  })
_sym_db.RegisterMessage(HuggingFaceIntegrationOptions)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.management.integration.apiP\001Z\034qwak/integration;integration'
  _HUGGINGFACEINTEGRATION._serialized_start=81
  _HUGGINGFACEINTEGRATION._serialized_end=245
  _HUGGINGFACEINTEGRATIONSPEC._serialized_start=248
  _HUGGINGFACEINTEGRATIONSPEC._serialized_end=390
  _HUGGINGFACEVALIDATIONSPEC._serialized_start=393
  _HUGGINGFACEVALIDATIONSPEC._serialized_end=534
  _HUGGINGFACEAPITOKENAUTHCONFIG._serialized_start=536
  _HUGGINGFACEAPITOKENAUTHCONFIG._serialized_end=586
  _HUGGINGFACEAPITOKENSYSTEMSECRETDESCRIPTOR._serialized_start=588
  _HUGGINGFACEAPITOKENSYSTEMSECRETDESCRIPTOR._serialized_end=682
  _HUGGINGFACEINTEGRATIONOPTIONS._serialized_start=684
  _HUGGINGFACEINTEGRATIONOPTIONS._serialized_end=715
# @@protoc_insertion_point(module_scope)



from frogml_storage.models.frogml_entity_type_info import FrogMLEntityTypeInfo


# The following method affect e2e tests.
def build_download_success_log(
    entity_type_info: FrogMLEntityTypeInfo, entity_name: str, version: str
) -> str:
    return (
        f'{entity_type_info.entity_type.capitalize()}: "{entity_name}", version: "{version}"'
        f" has been downloaded successfully"
    )


# The following method affect e2e tests.
def build_upload_success_log(
    entity_type_info: FrogMLEntityTypeInfo, entity_name: str, version: str
) -> str:
    return (
        f'{entity_type_info.entity_type.capitalize()}: "{entity_name}", version: "{version}"'
        f" has been uploaded successfully"
    )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetAuthTokenIdByFeaturesetIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    account_id: builtins.str
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "featureset_id", b"featureset_id"]) -> None: ...

global___GetAuthTokenIdByFeaturesetIdRequest = GetAuthTokenIdByFeaturesetIdRequest

class GetAuthTokenIdByFeaturesetIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_ID_FIELD_NUMBER: builtins.int
    token_id: builtins.str
    def __init__(
        self,
        *,
        token_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token_id", b"token_id"]) -> None: ...

global___GetAuthTokenIdByFeaturesetIdResponse = GetAuthTokenIdByFeaturesetIdResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/jobs/reports/report.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.execution.v1 import backfill_pb2 as qwak_dot_execution_dot_v1_dot_backfill__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/execution/v1/jobs/reports/report.proto\x12,qwak.feature.store.execution.v1.jobs.reports\x1a qwak/execution/v1/backfill.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"+\n\x12\x46\x61ilureInformation\x12\x15\n\rerror_message\x18\x01 \x01(\t\"\xd5\x01\n\x19\x42\x61tchIngestionJobMetadata\x12\x38\n\x14\x62\x61tch_execution_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x1bingestion_window_start_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x19ingestion_window_end_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xbe\x03\n\x18\x42\x61tchBackfillJobMetadata\x12\x19\n\x11num_interval_rows\x18\x01 \x01(\x03\x12\x44\n\rbackfill_spec\x18\x02 \x01(\x0b\x32-.qwak.feature.store.execution.v1.BackfillSpec\x12\x41\n\x1doffline_processing_start_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x1boffline_processing_end_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12@\n\x1conline_processing_start_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x1aonline_processing_end_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x17last_batch_logical_date\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"(\n\x14StreamingJobMetadata\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\x04\"!\n\x1fStreamingAggregationJobMetadata\"\xb6\x08\n\tJobReport\x12k\n\x18\x62\x61tch_ingestion_metadata\x18\x01 \x01(\x0b\x32G.qwak.feature.store.execution.v1.jobs.reports.BatchIngestionJobMetadataH\x00\x12\x64\n\x16streaming_job_metadata\x18\x02 \x01(\x0b\x32\x42.qwak.feature.store.execution.v1.jobs.reports.StreamingJobMetadataH\x00\x12t\n\x1bstreaming_aggr_job_metadata\x18\x03 \x01(\x0b\x32M.qwak.feature.store.execution.v1.jobs.reports.StreamingAggregationJobMetadataH\x00\x12m\n\x1b\x62\x61tch_backfill_job_metadata\x18\x04 \x01(\x0b\x32\x46.qwak.feature.store.execution.v1.jobs.reports.BatchBackfillJobMetadataH\x00\x12\x1c\n\x14num_affected_records\x18\x05 \x01(\x03\x12\x32\n\x0erun_start_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0crun_end_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\rlegacy_run_id\x18\x08 \x01(\x03H\x01\x12\x16\n\x0c\x65xecution_id\x18\t \x01(\tH\x01\x12\x16\n\x0e\x65nvironment_id\x18\n \x01(\t\x12\x15\n\rfeatureset_id\x18\x0b \x01(\t\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x0c \x01(\t\x12G\n\x06status\x18\r \x01(\x0e\x32\x37.qwak.feature.store.execution.v1.jobs.reports.JobStatus\x12Z\n\njob_labels\x18\x0e \x03(\x0b\x32\x46.qwak.feature.store.execution.v1.jobs.reports.JobReport.JobLabelsEntry\x12\x0e\n\x06job_id\x18\x0f \x01(\t\x12P\n\x04info\x18\x10 \x01(\x0b\x32@.qwak.feature.store.execution.v1.jobs.reports.FailureInformationH\x02\x1a\x30\n\x0eJobLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x13\n\x11job_metadata_typeB\x16\n\x14\x65xecution_identifierB\x0e\n\x0c\x66\x61ilure_info*m\n\tJobStatus\x12\x16\n\x12JOB_STATUS_INVALID\x10\x00\x12\x16\n\x12JOB_STATUS_SUCCESS\x10\x01\x12\x16\n\x12JOB_STATUS_FAILURE\x10\x02\x12\x18\n\x14JOB_STATUS_TOO_EARLY\x10\x03\x42\x36\n2com.qwak.ai.features.execution.api.v1.jobs.reportsP\x01\x62\x06proto3')

_JOBSTATUS = DESCRIPTOR.enum_types_by_name['JobStatus']
JobStatus = enum_type_wrapper.EnumTypeWrapper(_JOBSTATUS)
JOB_STATUS_INVALID = 0
JOB_STATUS_SUCCESS = 1
JOB_STATUS_FAILURE = 2
JOB_STATUS_TOO_EARLY = 3


_FAILUREINFORMATION = DESCRIPTOR.message_types_by_name['FailureInformation']
_BATCHINGESTIONJOBMETADATA = DESCRIPTOR.message_types_by_name['BatchIngestionJobMetadata']
_BATCHBACKFILLJOBMETADATA = DESCRIPTOR.message_types_by_name['BatchBackfillJobMetadata']
_STREAMINGJOBMETADATA = DESCRIPTOR.message_types_by_name['StreamingJobMetadata']
_STREAMINGAGGREGATIONJOBMETADATA = DESCRIPTOR.message_types_by_name['StreamingAggregationJobMetadata']
_JOBREPORT = DESCRIPTOR.message_types_by_name['JobReport']
_JOBREPORT_JOBLABELSENTRY = _JOBREPORT.nested_types_by_name['JobLabelsEntry']
FailureInformation = _reflection.GeneratedProtocolMessageType('FailureInformation', (_message.Message,), {
  'DESCRIPTOR' : _FAILUREINFORMATION,
  '__module__' : 'qwak.execution.v1.jobs.reports.report_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.reports.FailureInformation)
  })
_sym_db.RegisterMessage(FailureInformation)

BatchIngestionJobMetadata = _reflection.GeneratedProtocolMessageType('BatchIngestionJobMetadata', (_message.Message,), {
  'DESCRIPTOR' : _BATCHINGESTIONJOBMETADATA,
  '__module__' : 'qwak.execution.v1.jobs.reports.report_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.reports.BatchIngestionJobMetadata)
  })
_sym_db.RegisterMessage(BatchIngestionJobMetadata)

BatchBackfillJobMetadata = _reflection.GeneratedProtocolMessageType('BatchBackfillJobMetadata', (_message.Message,), {
  'DESCRIPTOR' : _BATCHBACKFILLJOBMETADATA,
  '__module__' : 'qwak.execution.v1.jobs.reports.report_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.reports.BatchBackfillJobMetadata)
  })
_sym_db.RegisterMessage(BatchBackfillJobMetadata)

StreamingJobMetadata = _reflection.GeneratedProtocolMessageType('StreamingJobMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGJOBMETADATA,
  '__module__' : 'qwak.execution.v1.jobs.reports.report_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.reports.StreamingJobMetadata)
  })
_sym_db.RegisterMessage(StreamingJobMetadata)

StreamingAggregationJobMetadata = _reflection.GeneratedProtocolMessageType('StreamingAggregationJobMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGAGGREGATIONJOBMETADATA,
  '__module__' : 'qwak.execution.v1.jobs.reports.report_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.reports.StreamingAggregationJobMetadata)
  })
_sym_db.RegisterMessage(StreamingAggregationJobMetadata)

JobReport = _reflection.GeneratedProtocolMessageType('JobReport', (_message.Message,), {

  'JobLabelsEntry' : _reflection.GeneratedProtocolMessageType('JobLabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _JOBREPORT_JOBLABELSENTRY,
    '__module__' : 'qwak.execution.v1.jobs.reports.report_pb2'
    # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.reports.JobReport.JobLabelsEntry)
    })
  ,
  'DESCRIPTOR' : _JOBREPORT,
  '__module__' : 'qwak.execution.v1.jobs.reports.report_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.reports.JobReport)
  })
_sym_db.RegisterMessage(JobReport)
_sym_db.RegisterMessage(JobReport.JobLabelsEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n2com.qwak.ai.features.execution.api.v1.jobs.reportsP\001'
  _JOBREPORT_JOBLABELSENTRY._options = None
  _JOBREPORT_JOBLABELSENTRY._serialized_options = b'8\001'
  _JOBSTATUS._serialized_start=2028
  _JOBSTATUS._serialized_end=2137
  _FAILUREINFORMATION._serialized_start=160
  _FAILUREINFORMATION._serialized_end=203
  _BATCHINGESTIONJOBMETADATA._serialized_start=206
  _BATCHINGESTIONJOBMETADATA._serialized_end=419
  _BATCHBACKFILLJOBMETADATA._serialized_start=422
  _BATCHBACKFILLJOBMETADATA._serialized_end=868
  _STREAMINGJOBMETADATA._serialized_start=870
  _STREAMINGJOBMETADATA._serialized_end=910
  _STREAMINGAGGREGATIONJOBMETADATA._serialized_start=912
  _STREAMINGAGGREGATIONJOBMETADATA._serialized_end=945
  _JOBREPORT._serialized_start=948
  _JOBREPORT._serialized_end=2026
  _JOBREPORT_JOBLABELSENTRY._serialized_start=1917
  _JOBREPORT_JOBLABELSENTRY._serialized_end=1965
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/cluster/v2/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0 import runtime_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_runtime__config__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0 import network_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_network__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/administration/cluster/v2/cluster.proto\x12\x1eqwak.administration.cluster.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x41qwak/administration/runtime_configuration/v0/runtime_config.proto\x1a\x41qwak/administration/runtime_configuration/v0/network_config.proto\"\xbb\x01\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12K\n\rconfiguration\x18\x03 \x01(\x0b\x32\x34.qwak.administration.cluster.v2.ClusterConfiguration\x12I\n\x10\x63luster_metadata\x18\x04 \x01(\x0b\x32/.qwak.administration.cluster.v2.ClusterMetadata\"\xa5\x01\n\x0f\x43lusterMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x34\n\x10last_modified_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x04 \x01(\t\"\xb1\x02\n\x14\x43lusterConfiguration\x12\\\n\x19self_hosted_configuration\x18\x01 \x01(\x0b\x32\x37.qwak.administration.cluster.v2.SelfHostedConfigurationH\x00\x12^\n\x1aself_service_configuration\x18\x02 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.SelfServiceConfigurationH\x00\x12S\n\x14hybrid_configuration\x18\x03 \x01(\x0b\x32\x33.qwak.administration.cluster.v2.HybridConfigurationH\x00\x42\x06\n\x04type\"n\n\x17SelfHostedConfiguration\x12S\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x34.qwak.administration.cluster.v2.RuntimeConfiguration\"o\n\x18SelfServiceConfiguration\x12S\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x34.qwak.administration.cluster.v2.RuntimeConfiguration\"j\n\x13HybridConfiguration\x12S\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x34.qwak.administration.cluster.v2.RuntimeConfiguration\"\xf2\x01\n\x14RuntimeConfiguration\x12\x61\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x42.qwak.administration.runtime_configuration.v0.RuntimeConfiguration\x12w\n\x15network_configuration\x18\x02 \x01(\x0b\x32X.qwak.administration.runtime_configuration.v0.network_config.ClusterNetworkConfiguration\"y\n\x0b\x43lusterSpec\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12T\n\x12\x63onfiguration_spec\x18\x02 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.ClusterConfigurationSpec\"\xc1\x02\n\x18\x43lusterConfigurationSpec\x12`\n\x19self_hosted_configuration\x18\x01 \x01(\x0b\x32;.qwak.administration.cluster.v2.SelfHostedConfigurationSpecH\x00\x12\x62\n\x1aself_service_configuration\x18\x02 \x01(\x0b\x32<.qwak.administration.cluster.v2.SelfServiceConfigurationSpecH\x00\x12W\n\x14hybrid_configuration\x18\x03 \x01(\x0b\x32\x37.qwak.administration.cluster.v2.HybridConfigurationSpecH\x00\x42\x06\n\x04type\"v\n\x1bSelfHostedConfigurationSpec\x12W\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.RuntimeConfigurationSpec\"w\n\x1cSelfServiceConfigurationSpec\x12W\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.RuntimeConfigurationSpec\"r\n\x17HybridConfigurationSpec\x12W\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.RuntimeConfigurationSpec\"\xf6\x01\n\x18RuntimeConfigurationSpec\x12\x61\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x42.qwak.administration.runtime_configuration.v0.RuntimeConfiguration\x12w\n\x15network_configuration\x18\x02 \x01(\x0b\x32X.qwak.administration.runtime_configuration.v0.network_config.ClusterNetworkConfiguration\"V\n\x0c\x43lusterState\x12=\n\x05valid\x18\x01 \x01(\x0b\x32,.qwak.administration.cluster.v2.ClusterValidH\x00\x42\x07\n\x05state\"H\n\x0c\x43lusterValid\x12\x38\n\x07\x63luster\x18\x01 \x01(\x0b\x32\'.qwak.administration.cluster.v2.Cluster\"b\n\x0c\x43lusterBrief\x12R\n\x11installation_type\x18\x01 \x01(\x0e\x32\x37.qwak.administration.cluster.v2.ClusterInstallationType*\xbd\x01\n\x17\x43lusterInstallationType\x12%\n!CLUSTER_INSTALLATION_TYPE_INVALID\x10\x00\x12)\n%SELF_HOSTED_CLUSTER_INSTALLATION_TYPE\x10\x01\x12*\n&SELF_SERVICE_CLUSTER_INSTALLATION_TYPE\x10\x02\x12$\n HYBRID_CLUSTER_INSTALLATION_TYPE\x10\x03\x42\xb4\x01\n)com.qwak.ai.administration.api.cluster.v2P\x01Z\x84\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/cluster/v2;cluster_v2b\x06proto3')

_CLUSTERINSTALLATIONTYPE = DESCRIPTOR.enum_types_by_name['ClusterInstallationType']
ClusterInstallationType = enum_type_wrapper.EnumTypeWrapper(_CLUSTERINSTALLATIONTYPE)
CLUSTER_INSTALLATION_TYPE_INVALID = 0
SELF_HOSTED_CLUSTER_INSTALLATION_TYPE = 1
SELF_SERVICE_CLUSTER_INSTALLATION_TYPE = 2
HYBRID_CLUSTER_INSTALLATION_TYPE = 3


_CLUSTER = DESCRIPTOR.message_types_by_name['Cluster']
_CLUSTERMETADATA = DESCRIPTOR.message_types_by_name['ClusterMetadata']
_CLUSTERCONFIGURATION = DESCRIPTOR.message_types_by_name['ClusterConfiguration']
_SELFHOSTEDCONFIGURATION = DESCRIPTOR.message_types_by_name['SelfHostedConfiguration']
_SELFSERVICECONFIGURATION = DESCRIPTOR.message_types_by_name['SelfServiceConfiguration']
_HYBRIDCONFIGURATION = DESCRIPTOR.message_types_by_name['HybridConfiguration']
_RUNTIMECONFIGURATION = DESCRIPTOR.message_types_by_name['RuntimeConfiguration']
_CLUSTERSPEC = DESCRIPTOR.message_types_by_name['ClusterSpec']
_CLUSTERCONFIGURATIONSPEC = DESCRIPTOR.message_types_by_name['ClusterConfigurationSpec']
_SELFHOSTEDCONFIGURATIONSPEC = DESCRIPTOR.message_types_by_name['SelfHostedConfigurationSpec']
_SELFSERVICECONFIGURATIONSPEC = DESCRIPTOR.message_types_by_name['SelfServiceConfigurationSpec']
_HYBRIDCONFIGURATIONSPEC = DESCRIPTOR.message_types_by_name['HybridConfigurationSpec']
_RUNTIMECONFIGURATIONSPEC = DESCRIPTOR.message_types_by_name['RuntimeConfigurationSpec']
_CLUSTERSTATE = DESCRIPTOR.message_types_by_name['ClusterState']
_CLUSTERVALID = DESCRIPTOR.message_types_by_name['ClusterValid']
_CLUSTERBRIEF = DESCRIPTOR.message_types_by_name['ClusterBrief']
Cluster = _reflection.GeneratedProtocolMessageType('Cluster', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTER,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.Cluster)
  })
_sym_db.RegisterMessage(Cluster)

ClusterMetadata = _reflection.GeneratedProtocolMessageType('ClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERMETADATA,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.ClusterMetadata)
  })
_sym_db.RegisterMessage(ClusterMetadata)

ClusterConfiguration = _reflection.GeneratedProtocolMessageType('ClusterConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERCONFIGURATION,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.ClusterConfiguration)
  })
_sym_db.RegisterMessage(ClusterConfiguration)

SelfHostedConfiguration = _reflection.GeneratedProtocolMessageType('SelfHostedConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _SELFHOSTEDCONFIGURATION,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.SelfHostedConfiguration)
  })
_sym_db.RegisterMessage(SelfHostedConfiguration)

SelfServiceConfiguration = _reflection.GeneratedProtocolMessageType('SelfServiceConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _SELFSERVICECONFIGURATION,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.SelfServiceConfiguration)
  })
_sym_db.RegisterMessage(SelfServiceConfiguration)

HybridConfiguration = _reflection.GeneratedProtocolMessageType('HybridConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _HYBRIDCONFIGURATION,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.HybridConfiguration)
  })
_sym_db.RegisterMessage(HybridConfiguration)

RuntimeConfiguration = _reflection.GeneratedProtocolMessageType('RuntimeConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMECONFIGURATION,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.RuntimeConfiguration)
  })
_sym_db.RegisterMessage(RuntimeConfiguration)

ClusterSpec = _reflection.GeneratedProtocolMessageType('ClusterSpec', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERSPEC,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.ClusterSpec)
  })
_sym_db.RegisterMessage(ClusterSpec)

ClusterConfigurationSpec = _reflection.GeneratedProtocolMessageType('ClusterConfigurationSpec', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERCONFIGURATIONSPEC,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.ClusterConfigurationSpec)
  })
_sym_db.RegisterMessage(ClusterConfigurationSpec)

SelfHostedConfigurationSpec = _reflection.GeneratedProtocolMessageType('SelfHostedConfigurationSpec', (_message.Message,), {
  'DESCRIPTOR' : _SELFHOSTEDCONFIGURATIONSPEC,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.SelfHostedConfigurationSpec)
  })
_sym_db.RegisterMessage(SelfHostedConfigurationSpec)

SelfServiceConfigurationSpec = _reflection.GeneratedProtocolMessageType('SelfServiceConfigurationSpec', (_message.Message,), {
  'DESCRIPTOR' : _SELFSERVICECONFIGURATIONSPEC,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.SelfServiceConfigurationSpec)
  })
_sym_db.RegisterMessage(SelfServiceConfigurationSpec)

HybridConfigurationSpec = _reflection.GeneratedProtocolMessageType('HybridConfigurationSpec', (_message.Message,), {
  'DESCRIPTOR' : _HYBRIDCONFIGURATIONSPEC,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.HybridConfigurationSpec)
  })
_sym_db.RegisterMessage(HybridConfigurationSpec)

RuntimeConfigurationSpec = _reflection.GeneratedProtocolMessageType('RuntimeConfigurationSpec', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMECONFIGURATIONSPEC,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.RuntimeConfigurationSpec)
  })
_sym_db.RegisterMessage(RuntimeConfigurationSpec)

ClusterState = _reflection.GeneratedProtocolMessageType('ClusterState', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERSTATE,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.ClusterState)
  })
_sym_db.RegisterMessage(ClusterState)

ClusterValid = _reflection.GeneratedProtocolMessageType('ClusterValid', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERVALID,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.ClusterValid)
  })
_sym_db.RegisterMessage(ClusterValid)

ClusterBrief = _reflection.GeneratedProtocolMessageType('ClusterBrief', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERBRIEF,
  '__module__' : 'qwak.administration.cluster.v2.cluster_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.cluster.v2.ClusterBrief)
  })
_sym_db.RegisterMessage(ClusterBrief)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.administration.api.cluster.v2P\001Z\204\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/cluster/v2;cluster_v2'
  _CLUSTERINSTALLATIONTYPE._serialized_start=2807
  _CLUSTERINSTALLATIONTYPE._serialized_end=2996
  _CLUSTER._serialized_start=248
  _CLUSTER._serialized_end=435
  _CLUSTERMETADATA._serialized_start=438
  _CLUSTERMETADATA._serialized_end=603
  _CLUSTERCONFIGURATION._serialized_start=606
  _CLUSTERCONFIGURATION._serialized_end=911
  _SELFHOSTEDCONFIGURATION._serialized_start=913
  _SELFHOSTEDCONFIGURATION._serialized_end=1023
  _SELFSERVICECONFIGURATION._serialized_start=1025
  _SELFSERVICECONFIGURATION._serialized_end=1136
  _HYBRIDCONFIGURATION._serialized_start=1138
  _HYBRIDCONFIGURATION._serialized_end=1244
  _RUNTIMECONFIGURATION._serialized_start=1247
  _RUNTIMECONFIGURATION._serialized_end=1489
  _CLUSTERSPEC._serialized_start=1491
  _CLUSTERSPEC._serialized_end=1612
  _CLUSTERCONFIGURATIONSPEC._serialized_start=1615
  _CLUSTERCONFIGURATIONSPEC._serialized_end=1936
  _SELFHOSTEDCONFIGURATIONSPEC._serialized_start=1938
  _SELFHOSTEDCONFIGURATIONSPEC._serialized_end=2056
  _SELFSERVICECONFIGURATIONSPEC._serialized_start=2058
  _SELFSERVICECONFIGURATIONSPEC._serialized_end=2177
  _HYBRIDCONFIGURATIONSPEC._serialized_start=2179
  _HYBRIDCONFIGURATIONSPEC._serialized_end=2293
  _RUNTIMECONFIGURATIONSPEC._serialized_start=2296
  _RUNTIMECONFIGURATIONSPEC._serialized_end=2542
  _CLUSTERSTATE._serialized_start=2544
  _CLUSTERSTATE._serialized_end=2630
  _CLUSTERVALID._serialized_start=2632
  _CLUSTERVALID._serialized_end=2704
  _CLUSTERBRIEF._serialized_start=2706
  _CLUSTERBRIEF._serialized_end=2804
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/v0/environments/environment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.administration.v0.environments import configuration_pb2 as qwak_dot_administration_dot_v0_dot_environments_dot_configuration__pb2
from _qwak_proto.qwak.administration.v0.environments import personalization_pb2 as qwak_dot_administration_dot_v0_dot_environments_dot_personalization__pb2
from _qwak_proto.qwak.administration.account.v1 import account_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_account__pb2
from _qwak_proto.qwak.administration.cluster.v2 import cluster_pb2 as qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5qwak/administration/v0/environments/environment.proto\x12\x1fqwak.administration.environment\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x37qwak/administration/v0/environments/configuration.proto\x1a\x39qwak/administration/v0/environments/personalization.proto\x1a,qwak/administration/account/v1/account.proto\x1a,qwak/administration/cluster/v2/cluster.proto\"\xbe\x05\n\x0fQwakEnvironment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\ttenant_id\x18\x03 \x01(\tB\x02\x18\x01\x12\x12\n\naccount_id\x18\x08 \x01(\t\x12\x12\n\ncluster_id\x18\n \x01(\t\x12\x42\n\x0c\x61\x63\x63ount_tier\x18\x0b \x01(\x0e\x32,.qwak.administration.environment.AccountTier\x12\x46\n\x06status\x18\x04 \x01(\x0e\x32\x36.qwak.administration.environment.QwakEnvironmentStatus\x12T\n\rconfiguration\x18\x05 \x01(\x0b\x32=.qwak.administration.environment.QwakEnvironmentConfiguration\x12T\n\x0fpersonalization\x18\t \x01(\x0b\x32;.qwak.administration.environment.EnvironmentPersonalization\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_modified_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x19\n\x0fjfrog_tenant_id\x18\x0c \x01(\tH\x00\x12\x38\n\x07\x61\x63\x63ount\x18\r \x01(\x0b\x32\'.qwak.administration.account.v1.Account\x12\x43\n\rcluster_brief\x18\x0e \x01(\x0b\x32,.qwak.administration.cluster.v2.ClusterBriefB\x1a\n\x18optional_jfrog_tenant_id\"8\n%EnvironmentApplicationUserCredentials\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t*w\n\x15QwakEnvironmentStatus\x12\x1e\n\x1a\x45NVIRONMENT_STATUS_INVALID\x10\x00\x12\x1d\n\x19\x45NVIRONMENT_STATUS_ACTIVE\x10\x01\x12\x1f\n\x1b\x45NVIRONMENT_STATUS_DISABLED\x10\x02*L\n\x0b\x41\x63\x63ountTier\x12\x18\n\x14\x41\x43\x43OUNT_TIER_INVALID\x10\x00\x12\x08\n\x04\x46REE\x10\x01\x12\r\n\tVALIDATED\x10\x02\x12\n\n\x06PAYING\x10\x03\x42\xb2\x01\n\x1e\x63om.qwak.ai.administration.apiP\x01Z\x8d\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/environments;environment_v0b\x06proto3')

_QWAKENVIRONMENTSTATUS = DESCRIPTOR.enum_types_by_name['QwakEnvironmentStatus']
QwakEnvironmentStatus = enum_type_wrapper.EnumTypeWrapper(_QWAKENVIRONMENTSTATUS)
_ACCOUNTTIER = DESCRIPTOR.enum_types_by_name['AccountTier']
AccountTier = enum_type_wrapper.EnumTypeWrapper(_ACCOUNTTIER)
ENVIRONMENT_STATUS_INVALID = 0
ENVIRONMENT_STATUS_ACTIVE = 1
ENVIRONMENT_STATUS_DISABLED = 2
ACCOUNT_TIER_INVALID = 0
FREE = 1
VALIDATED = 2
PAYING = 3


_QWAKENVIRONMENT = DESCRIPTOR.message_types_by_name['QwakEnvironment']
_ENVIRONMENTAPPLICATIONUSERCREDENTIALS = DESCRIPTOR.message_types_by_name['EnvironmentApplicationUserCredentials']
QwakEnvironment = _reflection.GeneratedProtocolMessageType('QwakEnvironment', (_message.Message,), {
  'DESCRIPTOR' : _QWAKENVIRONMENT,
  '__module__' : 'qwak.administration.v0.environments.environment_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.QwakEnvironment)
  })
_sym_db.RegisterMessage(QwakEnvironment)

EnvironmentApplicationUserCredentials = _reflection.GeneratedProtocolMessageType('EnvironmentApplicationUserCredentials', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTAPPLICATIONUSERCREDENTIALS,
  '__module__' : 'qwak.administration.v0.environments.environment_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.EnvironmentApplicationUserCredentials)
  })
_sym_db.RegisterMessage(EnvironmentApplicationUserCredentials)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.qwak.ai.administration.apiP\001Z\215\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/environments;environment_v0'
  _QWAKENVIRONMENT.fields_by_name['tenant_id']._options = None
  _QWAKENVIRONMENT.fields_by_name['tenant_id']._serialized_options = b'\030\001'
  _QWAKENVIRONMENTSTATUS._serialized_start=1094
  _QWAKENVIRONMENTSTATUS._serialized_end=1213
  _ACCOUNTTIER._serialized_start=1215
  _ACCOUNTTIER._serialized_end=1291
  _QWAKENVIRONMENT._serialized_start=332
  _QWAKENVIRONMENT._serialized_end=1034
  _ENVIRONMENTAPPLICATIONUSERCREDENTIALS._serialized_start=1036
  _ENVIRONMENTAPPLICATIONUSERCREDENTIALS._serialized_end=1092
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.model_descriptor.open_ai_descriptor_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Prompt(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DEFAULT_VERSION_DEFINITION_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    PROMPT_SPEC_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Prompt name"""
    @property
    def default_version_definition(self) -> global___PromptVersionDefinition:
        """Prompt default version definition"""
    @property
    def metadata(self) -> global___PromptMetadata:
        """Prompt metadata"""
    @property
    def prompt_spec(self) -> global___PromptSpec:
        """Prompt spec"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        default_version_definition: global___PromptVersionDefinition | None = ...,
        metadata: global___PromptMetadata | None = ...,
        prompt_spec: global___PromptSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_version_definition", b"default_version_definition", "metadata", b"metadata", "prompt_spec", b"prompt_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_version_definition", b"default_version_definition", "metadata", b"metadata", "name", b"name", "prompt_spec", b"prompt_spec"]) -> None: ...

global___Prompt = Prompt

class PromptVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_NAME_FIELD_NUMBER: builtins.int
    PROMPT_VERSION_DEFINITION_FIELD_NUMBER: builtins.int
    prompt_name: builtins.str
    """Prompt name"""
    @property
    def prompt_version_definition(self) -> global___PromptVersionDefinition:
        """Prompt version definition"""
    def __init__(
        self,
        *,
        prompt_name: builtins.str = ...,
        prompt_version_definition: global___PromptVersionDefinition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["prompt_version_definition", b"prompt_version_definition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["prompt_name", b"prompt_name", "prompt_version_definition", b"prompt_version_definition"]) -> None: ...

global___PromptVersion = PromptVersion

class PromptVersionDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_NUMBER_FIELD_NUMBER: builtins.int
    VERSION_SPEC_FIELD_NUMBER: builtins.int
    VERSION_METADATA_FIELD_NUMBER: builtins.int
    version_number: builtins.int
    """Prompt version number"""
    @property
    def version_spec(self) -> global___PromptVersionSpec:
        """Prompt spec"""
    @property
    def version_metadata(self) -> global___PromptVersionMetadata:
        """Prompt version metadata"""
    def __init__(
        self,
        *,
        version_number: builtins.int = ...,
        version_spec: global___PromptVersionSpec | None = ...,
        version_metadata: global___PromptVersionMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["version_metadata", b"version_metadata", "version_spec", b"version_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["version_metadata", b"version_metadata", "version_number", b"version_number", "version_spec", b"version_spec"]) -> None: ...

global___PromptVersionDefinition = PromptVersionDefinition

class PromptBrief(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VERSION_BRIEFS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Prompt name"""
    @property
    def version_briefs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PromptVersionBrief]:
        """Prompt version briefs"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        version_briefs: collections.abc.Iterable[global___PromptVersionBrief] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "version_briefs", b"version_briefs"]) -> None: ...

global___PromptBrief = PromptBrief

class PromptVersionBrief(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_NUMBER_FIELD_NUMBER: builtins.int
    MODEL_PROVIDER_BRIEF_FIELD_NUMBER: builtins.int
    version_number: builtins.int
    """Prompt version number"""
    @property
    def model_provider_brief(self) -> global___ModelProviderBrief: ...
    def __init__(
        self,
        *,
        version_number: builtins.int = ...,
        model_provider_brief: global___ModelProviderBrief | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_provider_brief", b"model_provider_brief", "optional_model_provider_brief", b"optional_model_provider_brief"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_provider_brief", b"model_provider_brief", "optional_model_provider_brief", b"optional_model_provider_brief", "version_number", b"version_number"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_model_provider_brief", b"optional_model_provider_brief"]) -> typing_extensions.Literal["model_provider_brief"] | None: ...

global___PromptVersionBrief = PromptVersionBrief

class ModelProviderBrief(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_PROVIDER_CASE_NUMBER_FIELD_NUMBER: builtins.int
    model_provider_case_number: builtins.int
    """model provider case number as derived from `PromptModelDescriptor.ModelProviderCase`"""
    def __init__(
        self,
        *,
        model_provider_case_number: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_provider_case_number", b"model_provider_case_number"]) -> None: ...

global___ModelProviderBrief = ModelProviderBrief

class PromptSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    description: builtins.str
    """Prompt description"""
    def __init__(
        self,
        *,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description"]) -> None: ...

global___PromptSpec = PromptSpec

class PromptVersionSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    PROMPT_TEMPLATE_FIELD_NUMBER: builtins.int
    MODEL_DESCRIPTOR_FIELD_NUMBER: builtins.int
    description: builtins.str
    """Prompt version description"""
    @property
    def prompt_template(self) -> global___PromptTemplate:
        """The template of the prompt"""
    @property
    def model_descriptor(self) -> global___PromptModelDescriptor: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        prompt_template: global___PromptTemplate | None = ...,
        model_descriptor: global___PromptModelDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_descriptor", b"model_descriptor", "optional_model_descriptor", b"optional_model_descriptor", "prompt_template", b"prompt_template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "model_descriptor", b"model_descriptor", "optional_model_descriptor", b"optional_model_descriptor", "prompt_template", b"prompt_template"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_model_descriptor", b"optional_model_descriptor"]) -> typing_extensions.Literal["model_descriptor"] | None: ...

global___PromptVersionSpec = PromptVersionSpec

class PromptTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHAT_PROMPT_TEMPLATE_FIELD_NUMBER: builtins.int
    @property
    def chat_prompt_template(self) -> global___ChatPromptTemplate:
        """Chat prompt template"""
    def __init__(
        self,
        *,
        chat_prompt_template: global___ChatPromptTemplate | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chat_prompt_template", b"chat_prompt_template", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chat_prompt_template", b"chat_prompt_template", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["chat_prompt_template"] | None: ...

global___PromptTemplate = PromptTemplate

class ChatPromptTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHAT_MESSAGES_FIELD_NUMBER: builtins.int
    @property
    def chat_messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ChatMessage]:
        """Templated chat message"""
    def __init__(
        self,
        *,
        chat_messages: collections.abc.Iterable[global___ChatMessage] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["chat_messages", b"chat_messages"]) -> None: ...

global___ChatPromptTemplate = ChatPromptTemplate

class ChatMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    @property
    def role(self) -> global___PromptMessageRole:
        """Role"""
    @property
    def template(self) -> global___ChatMessageTemplate:
        """Chat message template"""
    def __init__(
        self,
        *,
        role: global___PromptMessageRole | None = ...,
        template: global___ChatMessageTemplate | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["role", b"role", "template", b"template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["role", b"role", "template", b"template"]) -> None: ...

global___ChatMessage = ChatMessage

class ChatMessageTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_TEMPLATE_FIELD_NUMBER: builtins.int
    @property
    def text_template(self) -> global___TextTemplate:
        """Text message template"""
    def __init__(
        self,
        *,
        text_template: global___TextTemplate | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["text_template", b"text_template", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["text_template", b"text_template", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["text_template"] | None: ...

global___ChatMessageTemplate = ChatMessageTemplate

class TextTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEMPLATE_FIELD_NUMBER: builtins.int
    template: builtins.str
    """Text template"""
    def __init__(
        self,
        *,
        template: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["template", b"template"]) -> None: ...

global___TextTemplate = TextTemplate

class PromptMessageRole(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HUMAN_ROLE_FIELD_NUMBER: builtins.int
    SYSTEM_ROLE_FIELD_NUMBER: builtins.int
    AI_ROLE_FIELD_NUMBER: builtins.int
    @property
    def human_role(self) -> global___HumanPromptMessageRole:
        """Human role"""
    @property
    def system_role(self) -> global___SystemPromptMessageRole:
        """System role"""
    @property
    def ai_role(self) -> global___AIPromptMessageRole:
        """AI role"""
    def __init__(
        self,
        *,
        human_role: global___HumanPromptMessageRole | None = ...,
        system_role: global___SystemPromptMessageRole | None = ...,
        ai_role: global___AIPromptMessageRole | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ai_role", b"ai_role", "human_role", b"human_role", "role", b"role", "system_role", b"system_role"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ai_role", b"ai_role", "human_role", b"human_role", "role", b"role", "system_role", b"system_role"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["role", b"role"]) -> typing_extensions.Literal["human_role", "system_role", "ai_role"] | None: ...

global___PromptMessageRole = PromptMessageRole

class HumanPromptMessageRole(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___HumanPromptMessageRole = HumanPromptMessageRole

class SystemPromptMessageRole(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SystemPromptMessageRole = SystemPromptMessageRole

class AIPromptMessageRole(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AIPromptMessageRole = AIPromptMessageRole

class PromptModelDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPEN_AI_PROVIDER_FIELD_NUMBER: builtins.int
    @property
    def open_ai_provider(self) -> global___PromptOpenAIProvider:
        """OpenAI provider"""
    def __init__(
        self,
        *,
        open_ai_provider: global___PromptOpenAIProvider | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_provider", b"model_provider", "open_ai_provider", b"open_ai_provider"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_provider", b"model_provider", "open_ai_provider", b"open_ai_provider"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["model_provider", b"model_provider"]) -> typing_extensions.Literal["open_ai_provider"] | None: ...

global___PromptModelDescriptor = PromptModelDescriptor

class PromptOpenAIProvider(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPEN_AI_MODEL_DESCRIPTOR_FIELD_NUMBER: builtins.int
    @property
    def open_ai_model_descriptor(self) -> qwak.model_descriptor.open_ai_descriptor_pb2.OpenAIModelDescriptor:
        """OpenAI model descriptor"""
    def __init__(
        self,
        *,
        open_ai_model_descriptor: qwak.model_descriptor.open_ai_descriptor_pb2.OpenAIModelDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["open_ai_model_descriptor", b"open_ai_model_descriptor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["open_ai_model_descriptor", b"open_ai_model_descriptor"]) -> None: ...

global___PromptOpenAIProvider = PromptOpenAIProvider

class PromptMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """When the prompt was created"""
    created_by: builtins.str
    """User who created the prompt"""
    def __init__(
        self,
        *,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_by: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "created_by", b"created_by"]) -> None: ...

global___PromptMetadata = PromptMetadata

class PromptVersionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """When the prompt version was created"""
    created_by: builtins.str
    """User who created the prompt version"""
    def __init__(
        self,
        *,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_by: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "created_by", b"created_by"]) -> None: ...

global___PromptVersionMetadata = PromptVersionMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/v1/common/jfrog_artifact/jfrog_artifact.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@qwak/feature_store/v1/common/jfrog_artifact/jfrog_artifact.proto\x12+qwak.feature.store.v1.common.jfrog_artifact\"\x1d\n\rJfrogArtifact\x12\x0c\n\x04path\x18\x01 \x01(\tBp\n2com.qwak.ai.feature.store.v1.common.jfrog_artifactP\x01Z8qwak/featurestore/v1/common/jfrog_artifact;jfrogartifactb\x06proto3')



_JFROGARTIFACT = DESCRIPTOR.message_types_by_name['JfrogArtifact']
JfrogArtifact = _reflection.GeneratedProtocolMessageType('JfrogArtifact', (_message.Message,), {
  'DESCRIPTOR' : _JFROGARTIFACT,
  '__module__' : 'qwak.feature_store.v1.common.jfrog_artifact.jfrog_artifact_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.v1.common.jfrog_artifact.JfrogArtifact)
  })
_sym_db.RegisterMessage(JfrogArtifact)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n2com.qwak.ai.feature.store.v1.common.jfrog_artifactP\001Z8qwak/featurestore/v1/common/jfrog_artifact;jfrogartifact'
  _JFROGARTIFACT._serialized_start=113
  _JFROGARTIFACT._serialized_end=142
# @@protoc_insertion_point(module_scope)



from _qwak_proto.qwak.execution.v1.execution_pb2 import (
    ExecutionEntry as ProtoExecutionEntry,
    ExecutionStatus as ProtoExecutionStatus,
)
from qwak.clients.feature_store.execution_management_client import (
    ExecutionManagementClient,
)
from qwak.exceptions import QwakException


class ExecutionQuery:
    @staticmethod
    def _get_execution_status_name(proto_execution_status: ProtoExecutionStatus) -> str:
        """
        Translates between the execution status enum and front-end
        @param proto_execution_status:
        @type proto_execution_status:
        @return: str representation of the execution status
        @rtype: str
        """
        if proto_execution_status == ProtoExecutionStatus.EXECUTION_STATUS_FAILED:
            return "failed"
        if proto_execution_status == ProtoExecutionStatus.EXECUTION_STATUS_QUEUED:
            return "queued"
        if proto_execution_status == ProtoExecutionStatus.EXECUTION_STATUS_INVALID:
            return "invalid"
        if proto_execution_status == ProtoExecutionStatus.EXECUTION_STATUS_PENDING:
            return "pending"
        if proto_execution_status == ProtoExecutionStatus.EXECUTION_STATUS_RUNNING:
            return "running"
        if proto_execution_status == ProtoExecutionStatus.EXECUTION_STATUS_CANCELLED:
            return "cancelled"
        if proto_execution_status == ProtoExecutionStatus.EXECUTION_STATUS_COMPLETED:
            return "completed"
        if (
            proto_execution_status
            == ProtoExecutionStatus.EXECUTION_STATUS_FAILED_SUBMISSION
        ):
            return "failed submission"
        if proto_execution_status == ProtoExecutionStatus.EXECUTION_STATUS_SUBMITTED:
            return "submitted"
        else:
            "unsupported"

    @staticmethod
    def get_execution_status_message(execution_id: str) -> str:
        """
        This method receives an execution id and generates an appropriate status message according to its type and
        status.
        @param execution_id: execution id to query the status for
        @type execution_id: str
        @return: execution state message
        @rtype: str
        """
        execution_management_client = ExecutionManagementClient()
        entry_type: str = ""
        featureset_name: str = ""

        proto_execution_entry: ProtoExecutionEntry = (
            execution_management_client.get_execution_entry(
                execution_id=execution_id
            ).execution_entry
        )

        if proto_execution_entry.WhichOneof("execution_type") == "backfill_spec":
            featureset_name: str = proto_execution_entry.backfill_spec.featureset_name
            entry_type = "backfill"
        elif proto_execution_entry.WhichOneof("execution_type") == "batch_ingestion":
            featureset_name: str = proto_execution_entry.batch_ingestion.featureset_name
            entry_type = "batch job"
        else:
            raise QwakException(
                f"Entry for execution id {execution_id} is of unsupported type"
            )

        proto_execution_status: ProtoExecutionStatus = (
            execution_management_client.get_execution_status(
                execution_id=execution_id
            ).execution_status
        )

        execution_status_name: str = ExecutionQuery._get_execution_status_name(
            proto_execution_status
        )

        return (
            f"Execution id for a {entry_type} for featureset {featureset_name}, "
            f"status is {execution_status_name}"
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/features/feature_set.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.feature_store.features import feature_set_types_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__types__pb2
from _qwak_proto.qwak.feature_store.entities import entity_pb2 as qwak_dot_feature__store_dot_entities_dot_entity__pb2
from _qwak_proto.qwak.feature_store.features import feature_set_state_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__state__pb2
from _qwak_proto.qwak.feature_store.features import feature_set_attribute_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__attribute__pb2
from _qwak_proto.qwak.feature_store.v1.common.source_code import source_code_pb2 as qwak_dot_feature__store_dot_v1_dot_common_dot_source__code_dot_source__code__pb2
from _qwak_proto.qwak.feature_store.repository.common import platform_pb2 as qwak_dot_feature__store_dot_repository_dot_common_dot_platform__pb2
from _qwak_proto.qwak.feature_store.platform import platform_details_pb2 as qwak_dot_feature__store_dot_platform_dot_platform__details__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-qwak/feature_store/features/feature_set.proto\x12\x1bqwak.feature.store.features\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x33qwak/feature_store/features/feature_set_types.proto\x1a(qwak/feature_store/entities/entity.proto\x1a\x33qwak/feature_store/features/feature_set_state.proto\x1a\x37qwak/feature_store/features/feature_set_attribute.proto\x1a:qwak/feature_store/v1/common/source_code/source_code.proto\x1a\x33qwak/feature_store/repository/common/platform.proto\x1a\x32qwak/feature_store/platform/platform_details.proto\"\xfc\x01\n\nFeatureSet\x12Q\n\x16\x66\x65\x61ture_set_definition\x18\x01 \x01(\x0b\x32\x31.qwak.feature.store.features.FeatureSetDefinition\x12\x41\n\x08metadata\x18\x02 \x01(\x0b\x32/.qwak.feature.store.features.FeatureSetMetadata\x12X\n\x1b\x64\x65ployed_models_in_use_link\x18\x03 \x03(\x0b\x32\x33.qwak.feature.store.features.DeployedModelInUseLink\"\xa5\x01\n\x0e\x46\x65\x61turesetInfo\x12P\n\x15\x66\x65\x61tureset_definition\x18\x01 \x01(\x0b\x32\x31.qwak.feature.store.features.FeatureSetDefinition\x12\x41\n\x08metadata\x18\x02 \x01(\x0b\x32/.qwak.feature.store.features.FeatureSetMetadata\"x\n\x11\x46\x65\x61turesetSummary\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12I\n\x10\x66\x65\x61ture_set_type\x18\x03 \x01(\x0e\x32/.qwak.feature.store.features.FeatureSetTypeView\"\xf6\x04\n\x14\x46\x65\x61tureSetDefinition\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x45\n\x10\x66\x65\x61ture_set_spec\x18\x02 \x01(\x0b\x32+.qwak.feature.store.features.FeatureSetSpec\x12:\n\x06status\x18\x03 \x01(\x0e\x32*.qwak.feature.store.features.FeatureStatus\x12g\n feature_set_last_execution_state\x18\x04 \x01(\x0e\x32\x39.qwak.feature.store.features.FeatureSetLastExecutionStateB\x02\x18\x01\x12U\n\x0e\x66\x65\x61ture_health\x18\x05 \x01(\x0e\x32\x39.qwak.feature.store.features.FeatureSetLastExecutionStateB\x02\x18\x01\x12K\n\x11\x66\x65\x61ture_set_state\x18\x06 \x03(\x0b\x32,.qwak.feature.store.features.FeatureSetStateB\x02\x18\x01\x12*\n\x1eqwak_internal_protocol_version\x18\x07 \x01(\x05\x42\x02\x18\x01\x12!\n\x19\x66\x65\x61tureset_version_number\x18\x08 \x01(\x05\x12H\n\x10platform_details\x18\t \x01(\x0b\x32,.qwak.feature.store.platform.PlatformDetailsH\x00\x42\x1d\n\x1b\x66\x65\x61tureset_platform_details\"\xdb\x04\n\x0e\x46\x65\x61tureSetSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x45\n\x08metadata\x18\x02 \x01(\x0b\x32\x33.qwak.feature.store.features.FeatureSetUserMetadata\x12\x16\n\ngit_commit\x18\x03 \x01(\tB\x02\x18\x01\x12=\n\x06\x65ntity\x18\x04 \x01(\x0b\x32-.qwak.feature.store.entities.EntityDefinition\x12\x45\n\x10\x66\x65\x61ture_set_type\x18\x05 \x01(\x0b\x32+.qwak.feature.store.features.FeatureSetType\x12\x36\n\x08\x66\x65\x61tures\x18\x06 \x03(\x0b\x32$.qwak.feature.store.features.Feature\x12*\n\x1eqwak_internal_protocol_version\x18\x07 \x01(\x05\x42\x02\x18\x01\x12V\n\x10source_code_spec\x18\x08 \x01(\x0b\x32\x38.qwak.feature.store.v1.common.source_code.SourceCodeSpecB\x02\x18\x01\x12P\n\x15\x66\x65\x61tureset_attributes\x18\t \x01(\x0b\x32\x31.qwak.feature.store.features.FeaturesetAttributes\x12$\n\x1a\x66\x65\x61tureset_repository_name\x18\n \x01(\tH\x00\x42\"\n featureset_repository_identifier\"\xb8\x01\n\x16\x46\x65\x61tureSetUserMetadata\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x64\n featureset_version_user_metadata\x18\x04 \x01(\x0b\x32:.qwak.feature.store.features.FeaturesetVersionUserMetadata\"0\n\x1d\x46\x65\x61turesetVersionUserMetadata\x12\x0f\n\x07\x63omment\x18\x01 \x01(\t\"\x85\x02\n\x12\x46\x65\x61tureSetMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x34\n\x10last_modified_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x04 \x01(\t\x12[\n\x1b\x66\x65\x61tureset_version_metadata\x18\x05 \x01(\x0b\x32\x36.qwak.feature.store.features.FeaturesetVersionMetadata\"_\n\x19\x46\x65\x61turesetVersionMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\">\n\x16\x44\x65ployedModelInUseLink\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x12\n\nmodel_name\x18\x02 \x01(\t\"5\n\x07\x46\x65\x61ture\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x01 \x01(\t\x12\x14\n\x0c\x66\x65\x61ture_type\x18\x02 \x01(\t\"\xa7\x01\n\x16\x44\x65ployedFeatureSetSpec\x12\x45\n\x10\x66\x65\x61ture_set_spec\x18\x01 \x01(\x0b\x32+.qwak.feature.store.features.FeatureSetSpec\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x02 \x01(\t\x12\x12\n\naccount_id\x18\x03 \x01(\t\x12\x1a\n\x12\x66\x65\x61tureset_version\x18\x04 \x01(\x05\"O\n\x0e\x46\x65\x61tureSetList\x12=\n\x0c\x66\x65\x61ture_sets\x18\x01 \x03(\x0b\x32\'.qwak.feature.store.features.FeatureSet*\xb4\x01\n\rFeatureStatus\x12\x0b\n\x07INVALID\x10\x00\x12\t\n\x05VALID\x10\x01\x12\x0b\n\x07\x44\x45LETED\x10\x02\x12\x17\n\x13REGISTRATION_FAILED\x10\x03\x12\x1c\n\x18REGISTRATION_IN_PROGRESS\x10\x04\x12\x18\n\x14\x44\x45LETION_IN_PROGRESS\x10\x05\x12\x13\n\x0f\x44\x45LETION_FAILED\x10\x06\x12\x18\n\x14\x42\x41\x43KFILL_IN_PROGRESS\x10\x07*\x92\x01\n\x19\x46\x65\x61turesetSchedulingState\x12\x1c\n\x18SCHEDULING_STATE_INVALID\x10\x00\x12\x1c\n\x18SCHEDULING_STATE_ENABLED\x10\x01\x12\x1b\n\x17SCHEDULING_STATE_PAUSED\x10\x02\x12\x1c\n\x18SCHEDULING_STATE_UNKNOWN\x10\x03\x42[\n&com.qwak.ai.feature.store.features.apiP\x01Z/qwak/featurestore/features;featurestorefeaturesb\x06proto3')

_FEATURESTATUS = DESCRIPTOR.enum_types_by_name['FeatureStatus']
FeatureStatus = enum_type_wrapper.EnumTypeWrapper(_FEATURESTATUS)
_FEATURESETSCHEDULINGSTATE = DESCRIPTOR.enum_types_by_name['FeaturesetSchedulingState']
FeaturesetSchedulingState = enum_type_wrapper.EnumTypeWrapper(_FEATURESETSCHEDULINGSTATE)
INVALID = 0
VALID = 1
DELETED = 2
REGISTRATION_FAILED = 3
REGISTRATION_IN_PROGRESS = 4
DELETION_IN_PROGRESS = 5
DELETION_FAILED = 6
BACKFILL_IN_PROGRESS = 7
SCHEDULING_STATE_INVALID = 0
SCHEDULING_STATE_ENABLED = 1
SCHEDULING_STATE_PAUSED = 2
SCHEDULING_STATE_UNKNOWN = 3


_FEATURESET = DESCRIPTOR.message_types_by_name['FeatureSet']
_FEATURESETINFO = DESCRIPTOR.message_types_by_name['FeaturesetInfo']
_FEATURESETSUMMARY = DESCRIPTOR.message_types_by_name['FeaturesetSummary']
_FEATURESETDEFINITION = DESCRIPTOR.message_types_by_name['FeatureSetDefinition']
_FEATURESETSPEC = DESCRIPTOR.message_types_by_name['FeatureSetSpec']
_FEATURESETUSERMETADATA = DESCRIPTOR.message_types_by_name['FeatureSetUserMetadata']
_FEATURESETVERSIONUSERMETADATA = DESCRIPTOR.message_types_by_name['FeaturesetVersionUserMetadata']
_FEATURESETMETADATA = DESCRIPTOR.message_types_by_name['FeatureSetMetadata']
_FEATURESETVERSIONMETADATA = DESCRIPTOR.message_types_by_name['FeaturesetVersionMetadata']
_DEPLOYEDMODELINUSELINK = DESCRIPTOR.message_types_by_name['DeployedModelInUseLink']
_FEATURE = DESCRIPTOR.message_types_by_name['Feature']
_DEPLOYEDFEATURESETSPEC = DESCRIPTOR.message_types_by_name['DeployedFeatureSetSpec']
_FEATURESETLIST = DESCRIPTOR.message_types_by_name['FeatureSetList']
FeatureSet = _reflection.GeneratedProtocolMessageType('FeatureSet', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESET,
  '__module__' : 'qwak.feature_store.features.feature_set_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.FeatureSet)
  })
_sym_db.RegisterMessage(FeatureSet)

FeaturesetInfo = _reflection.GeneratedProtocolMessageType('FeaturesetInfo', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETINFO,
  '__module__' : 'qwak.feature_store.features.feature_set_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.FeaturesetInfo)
  })
_sym_db.RegisterMessage(FeaturesetInfo)

FeaturesetSummary = _reflection.GeneratedProtocolMessageType('FeaturesetSummary', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETSUMMARY,
  '__module__' : 'qwak.feature_store.features.feature_set_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.FeaturesetSummary)
  })
_sym_db.RegisterMessage(FeaturesetSummary)

FeatureSetDefinition = _reflection.GeneratedProtocolMessageType('FeatureSetDefinition', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETDEFINITION,
  '__module__' : 'qwak.feature_store.features.feature_set_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.FeatureSetDefinition)
  })
_sym_db.RegisterMessage(FeatureSetDefinition)

FeatureSetSpec = _reflection.GeneratedProtocolMessageType('FeatureSetSpec', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETSPEC,
  '__module__' : 'qwak.feature_store.features.feature_set_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.FeatureSetSpec)
  })
_sym_db.RegisterMessage(FeatureSetSpec)

FeatureSetUserMetadata = _reflection.GeneratedProtocolMessageType('FeatureSetUserMetadata', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETUSERMETADATA,
  '__module__' : 'qwak.feature_store.features.feature_set_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.FeatureSetUserMetadata)
  })
_sym_db.RegisterMessage(FeatureSetUserMetadata)

FeaturesetVersionUserMetadata = _reflection.GeneratedProtocolMessageType('FeaturesetVersionUserMetadata', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETVERSIONUSERMETADATA,
  '__module__' : 'qwak.feature_store.features.feature_set_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.FeaturesetVersionUserMetadata)
  })
_sym_db.RegisterMessage(FeaturesetVersionUserMetadata)

FeatureSetMetadata = _reflection.GeneratedProtocolMessageType('FeatureSetMetadata', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETMETADATA,
  '__module__' : 'qwak.feature_store.features.feature_set_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.FeatureSetMetadata)
  })
_sym_db.RegisterMessage(FeatureSetMetadata)

FeaturesetVersionMetadata = _reflection.GeneratedProtocolMessageType('FeaturesetVersionMetadata', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETVERSIONMETADATA,
  '__module__' : 'qwak.feature_store.features.feature_set_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.FeaturesetVersionMetadata)
  })
_sym_db.RegisterMessage(FeaturesetVersionMetadata)

DeployedModelInUseLink = _reflection.GeneratedProtocolMessageType('DeployedModelInUseLink', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYEDMODELINUSELINK,
  '__module__' : 'qwak.feature_store.features.feature_set_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.DeployedModelInUseLink)
  })
_sym_db.RegisterMessage(DeployedModelInUseLink)

Feature = _reflection.GeneratedProtocolMessageType('Feature', (_message.Message,), {
  'DESCRIPTOR' : _FEATURE,
  '__module__' : 'qwak.feature_store.features.feature_set_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.Feature)
  })
_sym_db.RegisterMessage(Feature)

DeployedFeatureSetSpec = _reflection.GeneratedProtocolMessageType('DeployedFeatureSetSpec', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYEDFEATURESETSPEC,
  '__module__' : 'qwak.feature_store.features.feature_set_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.DeployedFeatureSetSpec)
  })
_sym_db.RegisterMessage(DeployedFeatureSetSpec)

FeatureSetList = _reflection.GeneratedProtocolMessageType('FeatureSetList', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETLIST,
  '__module__' : 'qwak.feature_store.features.feature_set_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.FeatureSetList)
  })
_sym_db.RegisterMessage(FeatureSetList)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.feature.store.features.apiP\001Z/qwak/featurestore/features;featurestorefeatures'
  _FEATURESETDEFINITION.fields_by_name['feature_set_last_execution_state']._options = None
  _FEATURESETDEFINITION.fields_by_name['feature_set_last_execution_state']._serialized_options = b'\030\001'
  _FEATURESETDEFINITION.fields_by_name['feature_health']._options = None
  _FEATURESETDEFINITION.fields_by_name['feature_health']._serialized_options = b'\030\001'
  _FEATURESETDEFINITION.fields_by_name['feature_set_state']._options = None
  _FEATURESETDEFINITION.fields_by_name['feature_set_state']._serialized_options = b'\030\001'
  _FEATURESETDEFINITION.fields_by_name['qwak_internal_protocol_version']._options = None
  _FEATURESETDEFINITION.fields_by_name['qwak_internal_protocol_version']._serialized_options = b'\030\001'
  _FEATURESETSPEC.fields_by_name['git_commit']._options = None
  _FEATURESETSPEC.fields_by_name['git_commit']._serialized_options = b'\030\001'
  _FEATURESETSPEC.fields_by_name['qwak_internal_protocol_version']._options = None
  _FEATURESETSPEC.fields_by_name['qwak_internal_protocol_version']._serialized_options = b'\030\001'
  _FEATURESETSPEC.fields_by_name['source_code_spec']._options = None
  _FEATURESETSPEC.fields_by_name['source_code_spec']._serialized_options = b'\030\001'
  _FEATURESTATUS._serialized_start=3234
  _FEATURESTATUS._serialized_end=3414
  _FEATURESETSCHEDULINGSTATE._serialized_start=3417
  _FEATURESETSCHEDULINGSTATE._serialized_end=3563
  _FEATURESET._serialized_start=482
  _FEATURESET._serialized_end=734
  _FEATURESETINFO._serialized_start=737
  _FEATURESETINFO._serialized_end=902
  _FEATURESETSUMMARY._serialized_start=904
  _FEATURESETSUMMARY._serialized_end=1024
  _FEATURESETDEFINITION._serialized_start=1027
  _FEATURESETDEFINITION._serialized_end=1657
  _FEATURESETSPEC._serialized_start=1660
  _FEATURESETSPEC._serialized_end=2263
  _FEATURESETUSERMETADATA._serialized_start=2266
  _FEATURESETUSERMETADATA._serialized_end=2450
  _FEATURESETVERSIONUSERMETADATA._serialized_start=2452
  _FEATURESETVERSIONUSERMETADATA._serialized_end=2500
  _FEATURESETMETADATA._serialized_start=2503
  _FEATURESETMETADATA._serialized_end=2764
  _FEATURESETVERSIONMETADATA._serialized_start=2766
  _FEATURESETVERSIONMETADATA._serialized_end=2861
  _DEPLOYEDMODELINUSELINK._serialized_start=2863
  _DEPLOYEDMODELINUSELINK._serialized_end=2925
  _FEATURE._serialized_start=2927
  _FEATURE._serialized_end=2980
  _DEPLOYEDFEATURESETSPEC._serialized_start=2983
  _DEPLOYEDFEATURESETSPEC._serialized_end=3150
  _FEATURESETLIST._serialized_start=3152
  _FEATURESETLIST._serialized_end=3231
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/internal/deployment/platform_details.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<qwak/execution/v1/internal/deployment/platform_details.proto\x12\x33qwak.feature.store.execution.v1.internal.deployment\"&\n\x0fPlatformDetails\x12\x13\n\x0bproject_key\x18\x01 \x01(\tB=\n9com.qwak.ai.features.execution.api.v1.internal.deploymentP\x01\x62\x06proto3')



_PLATFORMDETAILS = DESCRIPTOR.message_types_by_name['PlatformDetails']
PlatformDetails = _reflection.GeneratedProtocolMessageType('PlatformDetails', (_message.Message,), {
  'DESCRIPTOR' : _PLATFORMDETAILS,
  '__module__' : 'qwak.execution.v1.internal.deployment.platform_details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.internal.deployment.PlatformDetails)
  })
_sym_db.RegisterMessage(PlatformDetails)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n9com.qwak.ai.features.execution.api.v1.internal.deploymentP\001'
  _PLATFORMDETAILS._serialized_start=117
  _PLATFORMDETAILS._serialized_end=155
# @@protoc_insertion_point(module_scope)



import logging
import uuid
from contextlib import contextmanager
from datetime import datetime
from io import BytesIO
from typing import List, Optional, Tuple

import boto3
import pandas as pd
from _qwak_proto.qwak.administration.authenticated_user.v1.authenticated_user_service_pb2 import (
    GetCloudCredentialsResponse,
)
from qwak.clients.administration import AuthenticatedUserClient
from qwak.exceptions import QwakException


class FeatureSetExecutionUnit:
    name: str
    feature_set_type: str
    owner: str
    description: str = ""
    display_name: str = ""
    fs_manager_client = None
    entity_name: str
    entity_key: str = None

    INGESTION_PREFIX: str = "batch_ingestion_data"
    BATCH_FEATURE_SET_TYPE: str = "batch_feature_set"

    def __init__(
        self,
        name,
        feature_set_type,
        owner,
        description,
        display_name,
        fs_manager_client,
        entity_name,
        entity_keys,
    ):
        self.name = name
        self.feature_set_type = feature_set_type
        self.owner = owner
        self.description = description
        self.display_name = display_name
        self.fs_manager_client = fs_manager_client
        self.entity_name = entity_name
        self.entity_key = entity_keys[0]  # Currently we support a single key

    def get_name(self):
        return self.name

    def get_feature_set_type(self):
        return self.feature_set_type

    def run_now_batch(self):
        """
        Used to trigger batch feature set now.

        Args:
            None
        Returns:
            None
        """
        self.fs_manager_client.run_feature_set(self.name)

    def validate_ingest_type(self):
        """
        validate the type of the feature set is Batch feature set type

        Return:
            None or raise exception if the type is incorrect
        """
        if self.feature_set_type != self.BATCH_FEATURE_SET_TYPE:
            raise QwakException(
                f"ingest is not supported for [{self.feature_set_type}]"
            )

    def _get_max_min_durations(self) -> Tuple[int, int]:
        """
        get max and min duration for ingestion

        Returns:
            max and min values
        """
        max_duration_seconds = 12 * 60 * 60
        min_duration_seconds = 15 * 60
        return max_duration_seconds, min_duration_seconds

    def _validate_duration_seconds(
        self,
        max_duration_seconds: int,
        min_duration_seconds: int,
        duration_seconds: int,
    ):
        """
        Validate duration second is in the range of the min/max durations
        Returtns:
        None or raise exception if not valid
        """
        if (
            duration_seconds > max_duration_seconds
            or duration_seconds < min_duration_seconds
        ):
            raise QwakException(
                "duration_seconds maximum is 12 hours and minimum of 15 minutes"
            )

    def ingest_pandas_df(
        self, df_to_ingest, timestamp_column: str, duration_seconds: int = 1800
    ):
        """
        Used to explicitly ingest a Pandas DF into a Qwak registered batch feature set

        Args:
            df_to_ingest: Pandas DataFrame, the pandas dataframe to ingest to the bach feature set
            timestamp_column: str, the name of the timestamp column
            duration_seconds: int, for how many seconds the STS credential's duration will be issued for.
             AWS limits this to max of 12 hours and min of 15 minutes.
        Returns:
            None
        """
        self.ingest(
            spark_context=None,
            df_to_ingest=df_to_ingest,
            timestamp_column=timestamp_column,
            duration_seconds=duration_seconds,
        )

    def ingest(
        self,
        spark_context,
        df_to_ingest,
        timestamp_column: str,
        duration_seconds: int = 3600,
        executors_temp_dir: Optional[str] = None,
    ):
        """
        Used to explicitly ingest a DF from a spark context or pandas into a Qwak registered batch feature set
        Args:
            spark_context: pyspark.context.SparkContext
            df_to_ingest: pyspark.sql.dataframe.DataFrame or pandas dataframe, the dataframe to ingest to the bach feature set
            timestamp_column: str, the name of the timestamp column
            duration_seconds: int, for how many seconds the STS credential's duration will be issued for.
             AWS limits this to max of 12 hours and min of 15 minutes.
             executors_temp_dir: Optional[str], if passed, on spark ingestion failure this function will try to
             ingest using the temp directory path. this path needs to be accessible on all spark executors.
             otherwise a random temp directory is used
        Returns:
            None
        """
        self.validate_ingest_type()

        max_duration_seconds, min_duration_seconds = self._get_max_min_durations()

        self._validate_duration_seconds(
            max_duration_seconds, min_duration_seconds, duration_seconds
        )

        is_spark_context = (
            False
            if spark_context is None and isinstance(df_to_ingest, pd.DataFrame)
            else True
        )

        validated_df = self._validate_and_format_df(
            df_to_ingest, timestamp_column, is_spark_context
        )

        authentication_client = AuthenticatedUserClient()
        auth_client_details = authentication_client.get_details()
        temporary_cloud_credentials = authentication_client.get_cloud_credentials(
            duration_seconds
        )

        write_path = self._ingest_dataframe(
            spark_context,
            validated_df,
            is_spark_context,
            temporary_cloud_credentials,
            auth_client_details,
            executors_temp_dir,
        )

        self._trigger_feature_set(timestamp_column, write_path)

    def _validate_and_format_df(self, df, timestamp_column, is_spark_context: bool):
        """
        Validate the data frame

        Args:
            df: pyspark.sql.dataframe.DataFrame, df to validate
            timestamp_column: str, the name of the timestamp column
            is_spark_context: rather using spark or pandas
        Returns:
            validated and formatted df
        """
        if self.entity_key not in df.columns:
            raise QwakException(
                f"entity key column [{self.entity_key}] was not found in the DFs columns"
            )
        return self._validate_and_cast_date_column_to_timestamp(
            df, timestamp_column, is_spark_context
        )

    @staticmethod
    def _get_date_column_from_pandas_df(df, timestamp_column):
        """
        get relevant column from pandas data frame
        Args:
            df: pandas data frame
            timestamp_column: the time column name
        """

        date_column = [
            column_name for column_name in df.columns if column_name == timestamp_column
        ]
        return date_column

    @staticmethod
    def _get_date_column_from_spark_df(df, timestamp_column):
        """
        get relevant columns from spark dataframe
        Args:
            df: pyspark.sql.dataframe.DataFrame
            timestamp_column: the time column name
        returns:
            date column
        """
        date_column = [
            (column_name, dtype)
            for column_name, dtype in df.dtypes
            if column_name == timestamp_column
        ]
        return date_column

    def _validate_and_cast_date_column_to_timestamp(
        self, df, timestamp_column: str, is_spark_context: bool
    ):
        """
        Validate and cast the data frames' timestamp column

        Args:
            df: pyspark.sql.dataframe.DataFrame, df to validate
            timestamp_column: str, the name of the timestamp column
            is_spark_context: rather using spark or not
        Returns:
            validated and casted timestamp column df
        """

        date_column = (
            self._get_date_column_from_spark_df(df, timestamp_column)
            if is_spark_context
            else self._get_date_column_from_pandas_df(df, timestamp_column)
        )

        if not date_column:
            raise QwakException(
                f"defined timestamp column: [{timestamp_column}] was not found in the DF"
            )
        if is_spark_context:
            if date_column[0][1] != "timestamp":
                try:
                    from pyspark.sql.functions import col
                    from pyspark.sql.types import TimestampType

                    df = df.withColumn(
                        timestamp_column, col(timestamp_column).cast(TimestampType())
                    )
                    return df

                except Exception as e:
                    raise QwakException(
                        f"failed to cast: [{timestamp_column}] to TimestampType, error is: [{e}]"
                    )
        elif isinstance(df, pd.DataFrame):
            return df
        else:
            raise QwakException(
                f"failed to cast: [{timestamp_column}]. Not supported type of dataframe"
            )
        return df

    def write_spark_df_to_s3(
        self, spark_context, bucket, aws_temporary_credentials, df_to_ingest, write_path
    ):
        """
        write spark dataframe to s3
        Args:
            spark_context: the spark session
            bucket: bucket name
            aws_temporary_credentials: temporary credentials for writing to s3
            df_to_ingest: Dataframe to ingest
            write_path: path to write in s3

        Returns:
            write_path - path to parquets files
        """

        with self._set_aws_auth_credentials(
            spark_context,
            bucket,
            aws_temporary_credentials,
        ):
            df_to_ingest.write.parquet(write_path)
            return f"{write_path}/*"

    def _create_s3_boto_client(self, aws_temporary_credentials):
        aws_permissions_dict = {
            "aws_access_key_id": aws_temporary_credentials.access_key_id,
            "aws_secret_access_key": aws_temporary_credentials.secret_access_key,
            "aws_session_token": aws_temporary_credentials.session_token,
        }
        return boto3.Session(**aws_permissions_dict).client("s3")

    def write_pandas_df_to_s3(
        self, aws_temporary_credentials, bucket, df_to_ingest, write_path
    ):
        """
        write pandas dataframe to s3
        Args:
            aws_temporary_credentials: temporary credentials for writing to s3
            bucket: bucket name
            df_to_ingest: Dataframe to ingest
            write_path: path to write in s3
        Returns:
            None
        """

        s3_client = self._create_s3_boto_client(aws_temporary_credentials)
        out_buffer = BytesIO()
        df_to_ingest.to_parquet(out_buffer, index=False)
        filepath = write_path.split(f"{bucket}/")[1]
        s3_client.put_object(Bucket=bucket, Key=filepath, Body=out_buffer.getvalue())

    def _ingest_dataframe(
        self,
        spark_context,
        df_to_ingest,
        is_spark_context: bool,
        temporary_cloud_credentials: GetCloudCredentialsResponse,
        auth_client_details,
        executors_temp_dir: Optional[str],
    ) -> str:
        """
        Dump a dataframe to a cloud path

        Args:
            spark_context: pyspark.context.SparkContext
            df_to_ingest: pyspark.sql.dataframe.DataFrame, the spark dataframe to ingest to the bach feature set
            creds_duration_seconds: int, for how many seconds the STS credential's duration will be issued for.
             AWS limits this to max of 12 hours and min of 15 minutes.
            is_spark_context: Rather using spark or pandas
            executors_temp_dir: Optional[str], if passed, on spark ingestion failure this function will try to
             ingest using the temp directory path. this path needs to be accessible on all spark executors.
             otherwise a random temp directory is used
              Returns:
                Parquet dump path
        """
        credentials_type = temporary_cloud_credentials.cloud_credentials.WhichOneof(
            "credentials"
        )
        if credentials_type == "aws_temporary_credentials":
            bucket = auth_client_details.environment.configuration.object_storage_bucket

            aws_temporary_credentials = (
                temporary_cloud_credentials.cloud_credentials.aws_temporary_credentials
            )

            write_path = self._get_s3_ingestion_path(bucket)
            try:
                if is_spark_context:
                    try:
                        write_path = self.write_spark_df_to_s3(
                            spark_context,
                            bucket,
                            aws_temporary_credentials,
                            df_to_ingest,
                            write_path,
                        )
                        return write_path
                    except Exception:
                        logging.info(
                            "Ingesting dataframe using a local buffer directory"
                        )
                        write_path = self._write_df_as_parquet(
                            executors_temp_dir,
                            df_to_ingest,
                            bucket,
                            aws_temporary_credentials,
                            write_path,
                        )
                        return write_path

                elif not is_spark_context:
                    self.write_pandas_df_to_s3(
                        aws_temporary_credentials, bucket, df_to_ingest, write_path
                    )
                    return write_path
            except Exception as e:
                raise QwakException(f"Failed to write dataframe to s3, error is: [{e}]")
        else:
            raise QwakException("Received an unknown cloud credentials type")

    def _trigger_feature_set(self, timestamp_column: str, parquet_path: str):
        """
        Used to trigger a batch feature set on an explicit parquet path

        Args:
            timestamp_column: str, name of the timestamp column
            parquet_path: str, path to the parquet files to trigger the batch feature set upon
        Returns:
            None
        """
        self.fs_manager_client.run_parquet_batch_feature_set(
            feature_set_name=self.name,
            parquet_location=parquet_path,
            timestamp_column=timestamp_column,
        )

    def _get_s3_ingestion_path(self, bucket) -> str:
        """
        Used to trigger a batch feature set on an explicit parquet path

        Args:
            bucket: str,
        Returns:
            ingestion path
        """
        return (
            f"s3a://{bucket}/{self.INGESTION_PREFIX}/{self.name}/"
            f'{datetime.utcnow().strftime("%Y%m%dT%H%M%S")}/{uuid.uuid4()}'
        )

    @contextmanager
    def _set_aws_auth_credentials(
        self, spark_context, bucket: str, aws_temporary_credentials
    ):
        original_credentials_provider = spark_context._jsc.hadoopConfiguration().get(
            f"fs.s3a.bucket.{bucket}.aws.credentials.provider"
        )
        original_access_key_id = spark_context._jsc.hadoopConfiguration().get(
            f"fs.s3a.bucket.{bucket}.access.key"
        )
        original_secret_key = spark_context._jsc.hadoopConfiguration().get(
            f"fs.s3a.bucket.{bucket}.secret.key"
        )
        original_session_token = spark_context._jsc.hadoopConfiguration().get(
            f"fs.s3a.bucket.{bucket}.session.token"
        )

        spark_context._jsc.hadoopConfiguration().set(
            f"fs.s3a.bucket.{bucket}.aws.credentials.provider",
            "org.apache.hadoop.fs.s3a.TemporaryAWSCredentialsProvider",
        )
        spark_context._jsc.hadoopConfiguration().set(
            f"fs.s3a.bucket.{bucket}.access.key",
            aws_temporary_credentials.access_key_id,
        )
        spark_context._jsc.hadoopConfiguration().set(
            f"fs.s3a.bucket.{bucket}.secret.key",
            aws_temporary_credentials.secret_access_key,
        )
        spark_context._jsc.hadoopConfiguration().set(
            f"fs.s3a.bucket.{bucket}.session.token",
            aws_temporary_credentials.session_token,
        )
        yield

        self._replace_or_unset_hadoop_conf(
            spark_context,
            f"fs.s3a.bucket.{bucket}.aws.credentials.provider",
            original_credentials_provider,
        )
        self._replace_or_unset_hadoop_conf(
            spark_context,
            f"fs.s3a.bucket.{bucket}.access.key",
            original_access_key_id,
        )
        self._replace_or_unset_hadoop_conf(
            spark_context, f"fs.s3a.bucket.{bucket}.secret.key", original_secret_key
        )
        self._replace_or_unset_hadoop_conf(
            spark_context,
            f"fs.s3a.bucket.{bucket}.session.token",
            original_session_token,
        )

    @staticmethod
    def _replace_or_unset_hadoop_conf(spark_context, key, value):
        if value:
            spark_context._jsc.hadoopConfiguration().set(key, value)
        else:
            spark_context._jsc.hadoopConfiguration().unset(key)

    def _write_df_as_parquet(
        self,
        executors_temp_dir: Optional[str],
        df,
        s3_bucket: str,
        aws_temporary_credentials,
        s3_write_path: str,
    ):
        """
        Write the df as parquet file using, foreachPartition.
        each partition is written locally to each executor as a parquet file, and then uploaded to s3
        Args:
            executors_temp_dir: Optional[str], temp directory to us as parquet buffer, needs to exists on each executor
            df: pyspark.sql.dataframe.DataFrame, df to ingest
        """

        def _write_to_parquet(row_iter, temp_dir_path):
            import os
            import uuid

            if not os.access(temp_dir_path, os.W_OK):
                raise QwakException(f"`{temp_dir_path}` is not writeable")
            random_suffix = uuid.uuid4()
            materialized_rows = list(row_iter)
            columns = list(materialized_rows[0].asDict().keys())
            pd.DataFrame(materialized_rows, columns=columns).to_parquet(
                f"{temp_dir_path}/{random_suffix}.snappy.parquet"
            )

        def _upload_all_file_in_dir_to_s3(
            s3_client, s3_bucket, s3_write_path, temp_dir_path
        ):
            import glob
            import os

            files = glob.glob(temp_dir_path + "/*")
            filepath = s3_write_path.split(f"{s3_bucket}/")[1]
            try:
                for file in files:
                    s3_file = f"{filepath}/{os.path.basename(file)}"
                    s3_client.upload_file(file, s3_bucket, s3_file)
            except Exception as e:
                raise QwakException(
                    f"An unexpected error occurred uploading the data files to S3, got [{e}]"
                )

        def ingest_partition_to_s3_using_local_dir_buffer(
            row_iter: List[dict],
            s3_bucket: str,
            aws_permissions_dict: dict,
            s3_write_path: str,
            executors_temp_dir: str,
        ):
            """
            This method runs in parallel on each spark executor.
            Currently the whole logic is implemented here in order to avoid serialization problems.
            Args:
                row_iter: Iter[Row], the partition to ingest
                aws_permissions_dict: dict[str -> str], aws credentials dict
                s3_write_path: str,  s3 path for where to upload parquet files
                executors_temp_dir: str,  local directory on each executor to use as a local buffer
            """
            _write_to_parquet(row_iter, executors_temp_dir)

            s3_client = boto3.Session(
                aws_access_key_id=aws_permissions_dict["key"],
                aws_secret_access_key=aws_permissions_dict["secret"],
                aws_session_token=aws_permissions_dict["token"],
            ).client("s3")

            _upload_all_file_in_dir_to_s3(
                s3_client, s3_bucket, s3_write_path, executors_temp_dir
            )

        if not executors_temp_dir:
            import tempfile

            temp_dir = tempfile.TemporaryDirectory()
            executors_temp_dir = temp_dir.name

        aws_permissions_dict = {
            "key": aws_temporary_credentials.access_key_id,
            "secret": aws_temporary_credentials.secret_access_key,
            "token": aws_temporary_credentials.session_token,
        }

        lambda_injected_with_variables = (
            lambda row_iter: ingest_partition_to_s3_using_local_dir_buffer(
                row_iter,
                s3_bucket,
                aws_permissions_dict,
                s3_write_path,
                executors_temp_dir,
            )
        )
        df.foreachPartition(lambda_injected_with_variables)
        return f"{s3_write_path}/*"



import http
import json
import os
from typing import Optional, Tuple, Union, List

import requests
from requests.auth import AuthBase, HTTPBasicAuth

from frogml_storage.utils import join_url
from frogml_storage.artifactory import ArtifactoryApi
from frogml_storage.authentication.models import (
    BearerAuth,
    EmptyAuth,
    AuthConfig,
    LoginArguments,
)
from frogml_storage.constants import (
    CONFIG_FILE_PATH,
    FROG_ML_CONFIG_ACCESS_TOKEN,
    FROG_ML_CONFIG_ARTIFACTORY_URL,
    FROG_ML_CONFIG_PASSWORD,
    FROG_ML_CONFIG_USER,
    JF_ACCESS_TOKEN,
    JF_URL,
    JFROG_CLI_CONFIG_ACCESS_TOKEN,
    JFROG_CLI_CONFIG_ARTIFACTORY_URL,
    JFROG_CLI_CONFIG_FILE_PATH,
    JFROG_CLI_CONFIG_PASSWORD,
    JFROG_CLI_CONFIG_URL,
    JFROG_CLI_CONFIG_USER,
    SERVER_ID,
)
from frogml_storage.logging import logger


def read_jfrog_cli_config() -> Union[dict, None]:
    try:
        with open(JFROG_CLI_CONFIG_FILE_PATH, "r") as file:
            config_data = json.load(file)
            return config_data
    except FileNotFoundError:
        logger.debug("JFrog cli config file was not found.")
        return None
    except json.JSONDecodeError as e:
        print(f"JFrog cli config file is not a valid JSON {e}.")
        return None


def read_frogml_config() -> Union[dict, None]:
    try:
        with open(CONFIG_FILE_PATH, "r") as file:
            config_data = json.load(file)
            return config_data
    except FileNotFoundError:
        logger.debug("FrogMl config file was not found.")
        return None
    except json.JSONDecodeError as e:
        print(f"FrogMl config file is not a valid JSON {e}.")
        return None


def parse_cli_config_server(server_config: dict) -> Union[LoginArguments, None]:
    login_args = LoginArguments()
    login_args.server_id = server_config.get(SERVER_ID)

    if JFROG_CLI_CONFIG_ARTIFACTORY_URL in server_config:
        login_args.artifactory_url = server_config.get(JFROG_CLI_CONFIG_ARTIFACTORY_URL)
    elif (
        JFROG_CLI_CONFIG_URL in server_config
        and server_config.get(JFROG_CLI_CONFIG_URL) is not None
    ):
        login_args.artifactory_url = join_url(
            server_config[JFROG_CLI_CONFIG_URL], "artifactory"
        )
    else:
        logger.debug(
            "Invalid JFrog CLI file, expected either artifactoryUrl or url in jfrog cli config file"
        )
        return None

    if JFROG_CLI_CONFIG_ACCESS_TOKEN in server_config:
        login_args.access_token = server_config.get(JFROG_CLI_CONFIG_ACCESS_TOKEN)
    elif (
        JFROG_CLI_CONFIG_USER in server_config
        and JFROG_CLI_CONFIG_PASSWORD in server_config
    ):
        login_args.username = server_config.get(JFROG_CLI_CONFIG_USER)
        login_args.password = server_config.get(JFROG_CLI_CONFIG_PASSWORD)
    else:
        logger.debug(
            "Expected either accessToken or user/password in jfrog cli config file"
        )
        return None

    return login_args


def get_frogml_configuration() -> Union[LoginArguments, None]:
    frog_ml_config = read_frogml_config()
    if (
        frog_ml_config is not None
        and frog_ml_config.get("servers") is not None
        and len(frog_ml_config["servers"]) > 0
    ):
        server_config = frog_ml_config["servers"][0]
        login_args = LoginArguments()
        if FROG_ML_CONFIG_ARTIFACTORY_URL in server_config:
            login_args.artifactory_url = server_config.get(
                FROG_ML_CONFIG_ARTIFACTORY_URL
            )
        else:
            logger.debug(
                "Invalid FrogMl authentication file, expected either artifactory_url in FrogMl authentication file"
            )
            return None

        if FROG_ML_CONFIG_ACCESS_TOKEN in server_config:
            login_args.access_token = server_config.get(FROG_ML_CONFIG_ACCESS_TOKEN)
        elif (
            FROG_ML_CONFIG_USER in server_config
            and FROG_ML_CONFIG_PASSWORD in server_config
        ):
            login_args.username = server_config.get(FROG_ML_CONFIG_USER)
            login_args.password = server_config.get(FROG_ML_CONFIG_PASSWORD)
        elif (
            FROG_ML_CONFIG_USER in server_config
            and FROG_ML_CONFIG_PASSWORD not in server_config
            or (
                FROG_ML_CONFIG_USER not in server_config
                and FROG_ML_CONFIG_PASSWORD in server_config
            )
        ):
            logger.debug(
                "Invalid FrogMl authentication file, username or password is missing in FrogMl authentication file"
            )
            return None
        elif (
            login_args.username is None
            and login_args.password is None
            and login_args.access_token is None
        ):
            login_args.isAnonymous = True
        return login_args
    else:
        return None


def get_encrypted_password(
    auth_config: AuthConfig, auth_token: AuthBase
) -> Optional[str]:
    try:
        response = ArtifactoryApi(
            auth_config.artifactory_url, auth_token
        ).encrypt_password()
        if response.status_code != http.HTTPStatus.OK:
            logger.debug(
                f"Expected {http.HTTPStatus.OK} status but got {response.status_code} "
                f"when using url {auth_config.artifactory_url}"
            )
            print("Error while trying to encrypt password.")
            return None
        return response.text
    except requests.exceptions.RequestException as e:
        print(f"Error while trying to encrypt password: {e}.")
        return None


def save_auth_config(auth_config: AuthConfig) -> None:
    file_content: dict[str, list] = {}
    file_content.setdefault("servers", []).append(auth_config.to_json())
    os.makedirs(os.path.dirname(CONFIG_FILE_PATH), exist_ok=True)
    with open(CONFIG_FILE_PATH, "w") as file:
        json.dump(file_content, file, indent=2)


def get_credentials(auth_config: Optional[AuthConfig] = None) -> Tuple[str, AuthBase]:
    if not __should_use_file_auth(auth_config):
        __validate_credentials(auth_config)
        return __auth_config_to_auth_tuple(auth_config)
    logger.debug(
        "Login configuration not supplied, attempting to find environment variables"
    )

    if __should_use_environment_variables():
        return get_environment_variables()

    logger.debug(
        "Environment variables not supplied, attempting to load configuration from file"
    )

    if os.path.exists(CONFIG_FILE_PATH):
        return __read_credentials_from_file(CONFIG_FILE_PATH)
    raise ValueError(
        f"Configuration were not provided and configuration file not found in {CONFIG_FILE_PATH},"
        f" either pass configuration in the constructor, add env variables or create the configuration file by "
        f"running `frogml login`"
    )


def __should_use_environment_variables() -> bool:
    return os.getenv("JF_URL") is not None


def get_environment_variables() -> Tuple[str, AuthBase]:
    auth_config: AuthConfig = AuthConfig(
        artifactory_url=os.getenv(JF_URL),
        access_token=os.getenv(JF_ACCESS_TOKEN),
    )

    return __auth_config_to_auth_tuple(auth_config)


def __should_use_file_auth(credentials: Optional[AuthConfig] = None) -> bool:
    return credentials is None or (
        credentials.artifactory_url is None
        and credentials.user is None
        and credentials.password is None
        and credentials.access_token is None
    )


def __validate_credentials(credentials: Optional[AuthConfig]) -> None:
    if credentials is None:
        raise ValueError("Credentials must be provided.")
    if credentials.artifactory_url is None:
        raise ValueError("Credentials must contain artifactory url.")
    return None


def __read_credentials_from_file(file_path: str) -> Tuple[str, AuthBase]:
    try:
        with open(file_path, "r") as file:
            config_content: dict = json.load(file)
            servers = config_content.get("servers")
            if servers is None or len(servers) == 0:
                raise ValueError(
                    "Configuration file was found but it's empty, failing authentication"
                )
            server = servers[0]
            return __auth_config_to_auth_tuple(AuthConfig.from_dict(server))
    except json.JSONDecodeError:
        raise ValueError(f"Error when reading {file_path}, please recreate the file.")


def __auth_config_to_auth_tuple(
    auth_config: Optional[AuthConfig],
) -> Tuple[str, AuthBase]:

    if auth_config is None:
        raise ValueError("No authentication configuration provided")

    auth: AuthBase = EmptyAuth()
    if auth_config.access_token is not None:
        auth = BearerAuth(auth_config.access_token)
    elif auth_config.user is not None and auth_config.password is not None:
        auth = HTTPBasicAuth(auth_config.user, auth_config.password)
    elif auth_config.user is not None or auth_config.password is not None:
        raise ValueError("User and password must be provided together")

    if auth_config.artifactory_url is None:
        raise ValueError("No artifactory URL provided")

    return auth_config.artifactory_url, auth


def get_list_of_servers_from_config(jfrog_cli_config: dict) -> List[str]:
    if jfrog_cli_config is not None:
        servers = jfrog_cli_config.get("servers")
        if servers is not None:
            return list(map(__map_server_ids, servers))

    return []


def __map_server_ids(server: dict) -> str:
    server_id = ""
    if server is not None:
        server_id = str(server.get("serverId"))
        if server.get("isDefault") is not None and bool(server.get("isDefault")):
            server_id = server_id + " (Default)"
    return server_id



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.features_operator.v1 import features_operator_service_pb2 as qwak_dot_features__operator_dot_v1_dot_features__operator__service__pb2


class FeaturesOperatorServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ValidateDataSource = channel.unary_unary(
                '/qwak.features_operator.v1.FeaturesOperatorService/ValidateDataSource',
                request_serializer=qwak_dot_features__operator_dot_v1_dot_features__operator__service__pb2.ValidateDataSourceRequest.SerializeToString,
                response_deserializer=qwak_dot_features__operator_dot_v1_dot_features__operator__service__pb2.ValidationResponse.FromString,
                )
        self.ValidateFeatureSet = channel.unary_unary(
                '/qwak.features_operator.v1.FeaturesOperatorService/ValidateFeatureSet',
                request_serializer=qwak_dot_features__operator_dot_v1_dot_features__operator__service__pb2.ValidateFeatureSetRequest.SerializeToString,
                response_deserializer=qwak_dot_features__operator_dot_v1_dot_features__operator__service__pb2.ValidationResponse.FromString,
                )


class FeaturesOperatorServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ValidateDataSource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateFeatureSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeaturesOperatorServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ValidateDataSource': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateDataSource,
                    request_deserializer=qwak_dot_features__operator_dot_v1_dot_features__operator__service__pb2.ValidateDataSourceRequest.FromString,
                    response_serializer=qwak_dot_features__operator_dot_v1_dot_features__operator__service__pb2.ValidationResponse.SerializeToString,
            ),
            'ValidateFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateFeatureSet,
                    request_deserializer=qwak_dot_features__operator_dot_v1_dot_features__operator__service__pb2.ValidateFeatureSetRequest.FromString,
                    response_serializer=qwak_dot_features__operator_dot_v1_dot_features__operator__service__pb2.ValidationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.features_operator.v1.FeaturesOperatorService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeaturesOperatorService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ValidateDataSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.features_operator.v1.FeaturesOperatorService/ValidateDataSource',
            qwak_dot_features__operator_dot_v1_dot_features__operator__service__pb2.ValidateDataSourceRequest.SerializeToString,
            qwak_dot_features__operator_dot_v1_dot_features__operator__service__pb2.ValidationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.features_operator.v1.FeaturesOperatorService/ValidateFeatureSet',
            qwak_dot_features__operator_dot_v1_dot_features__operator__service__pb2.ValidateFeatureSetRequest.SerializeToString,
            qwak_dot_features__operator_dot_v1_dot_features__operator__service__pb2.ValidationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from typing import Optional

import grpc
from _qwak_proto.qwak.admiral.user_application_instance.v0.user_application_instance_pb2 import (
    CreateOptions,
    Identifier,
    RevisionRestriction,
    UpdateSpecOptions,
)
from _qwak_proto.qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2 import (
    CreateUserApplicationInstanceRequest,
    CreateUserApplicationInstanceResponse,
    DeleteUserApplicationInstanceRequest,
    DeleteUserApplicationInstanceResponse,
    GetUserApplicationInstanceRequest,
    GetUserApplicationInstanceResponse,
    UpdateUserApplicationInstanceSpecRequest,
    UpdateUserApplicationInstanceSpecResponse,
)
from _qwak_proto.qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2_grpc import (
    UserApplicationInstanceServiceStub,
)
from _qwak_proto.qwak.user_application.v0.user_application_pb2 import Spec, Type
from dependency_injector.wiring import Provide
from qwak.exceptions import QwakException, QwakNotFoundException
from qwak.inner.di_configuration import QwakContainer


class UserApplicationInstanceClient:
    """
    Used for interacting with Feature Registry endpoints
    """

    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self._user_application_instance_service = UserApplicationInstanceServiceStub(
            grpc_channel
        )

    def create_user_application_instance(
        self,
        kind_sem_version: Optional[str],
        account_id: str,
        environment_id: str,
        name: str,
        type: Type,
        spec: Spec,
    ) -> CreateUserApplicationInstanceResponse:
        """
        Create user application instance
        """
        try:
            identifier = Identifier(
                account_id=account_id,
                environment_id=environment_id,
                name=name,
                type=type,
            )

            create_options = CreateOptions(
                identifier=identifier, spec=spec, kind_sem_version=kind_sem_version
            )
            create_user_application_instance_request = (
                CreateUserApplicationInstanceRequest(create_options=create_options)
            )

            return (
                self._user_application_instance_service.CreateUserApplicationInstance(
                    create_user_application_instance_request
                )
            )
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to create user application instance, error is {repr(e)}"
            )

    def update_user_application_instance(
        self,
        current_spec_revision: Optional[int],
        account_id: str,
        environment_id: str,
        name: str,
        type: Type,
        spec: Spec,
    ) -> UpdateUserApplicationInstanceSpecResponse:
        """
        Update user application instance
        """
        try:
            identifier = Identifier(
                account_id=account_id,
                environment_id=environment_id,
                name=name,
                type=type,
            )

            revision_restriction = RevisionRestriction(
                current_spec_revision=current_spec_revision
            )
            update_options = UpdateSpecOptions(
                identifier=identifier,
                spec=spec,
                revision_restriction=revision_restriction,
            )
            update_user_application_instance_request = (
                UpdateUserApplicationInstanceSpecRequest(update_options=update_options)
            )

            return self._user_application_instance_service.UpdateUserApplicationInstanceSpec(
                update_user_application_instance_request
            )
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to update user application instance, error is {repr(e)}"
            )

    def delete_user_application_instance(
        self,
        account_id: str,
        environment_id: str,
        name: str,
        type: Type,
    ) -> DeleteUserApplicationInstanceResponse:
        """
        Delete user application instance
        """
        try:
            identifier = Identifier(
                account_id=account_id,
                environment_id=environment_id,
                name=name,
                type=type,
            )
            delete_user_application_instance_request = (
                DeleteUserApplicationInstanceRequest(identifier=identifier)
            )
            return (
                self._user_application_instance_service.DeleteUserApplicationInstance(
                    delete_user_application_instance_request
                )
            )
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to delete user application instance, error is {repr(e)}"
            )

    def get_user_application_instance(
        self,
        account_id: str,
        environment_id: str,
        name: str,
        type: Type,
    ) -> GetUserApplicationInstanceResponse:
        """
        Get user application instance
        """
        try:
            identifier = Identifier(
                account_id=account_id,
                environment_id=environment_id,
                name=name,
                type=type,
            )
            get_user_application_request = GetUserApplicationInstanceRequest(
                identifier=identifier
            )
            return self._user_application_instance_service.GetUserApplicationInstance(
                get_user_application_request
            )
        except grpc.RpcError as e:
            if e.args[0].code == grpc.StatusCode.NOT_FOUND:
                raise QwakNotFoundException(
                    f"User application instance  Resource was not found, error is {repr(e)}"
                )
            raise QwakException(
                f"Failed to get user application instance, error is {repr(e)}"
            )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Type:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Type.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID_USER_APPLICATION_TYPE: _Type.ValueType  # 0
    REMOTE_BUILD: _Type.ValueType  # 1
    BATCH_FEATURE_PROCESSOR: _Type.ValueType  # 2
    STREAMING_FEATURE_PROCESSOR: _Type.ValueType  # 3
    BATCH_INFERENCE_TASK: _Type.ValueType  # 4
    MODEL_DEPLOYMENT: _Type.ValueType  # 5
    MODEL_MONITOR: _Type.ValueType  # 6
    DEPLOYMENT_MICROSERVICE: _Type.ValueType  # 7
    APPLICATION: _Type.ValueType  # 8
    BATCH_FEATURESET: _Type.ValueType  # 9
    CUSTOMER_ALERT_STACK: _Type.ValueType  # 10
    MODEL_TRAFFIC: _Type.ValueType  # 11
    STREAMING_FEATURESET: _Type.ValueType  # 12
    STREAMING_AGGREGATION_FEATURESET: _Type.ValueType  # 13

class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...

INVALID_USER_APPLICATION_TYPE: Type.ValueType  # 0
REMOTE_BUILD: Type.ValueType  # 1
BATCH_FEATURE_PROCESSOR: Type.ValueType  # 2
STREAMING_FEATURE_PROCESSOR: Type.ValueType  # 3
BATCH_INFERENCE_TASK: Type.ValueType  # 4
MODEL_DEPLOYMENT: Type.ValueType  # 5
MODEL_MONITOR: Type.ValueType  # 6
DEPLOYMENT_MICROSERVICE: Type.ValueType  # 7
APPLICATION: Type.ValueType  # 8
BATCH_FEATURESET: Type.ValueType  # 9
CUSTOMER_ALERT_STACK: Type.ValueType  # 10
MODEL_TRAFFIC: Type.ValueType  # 11
STREAMING_FEATURESET: Type.ValueType  # 12
STREAMING_AGGREGATION_FEATURESET: Type.ValueType  # 13
global___Type = Type

class Spec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    @property
    def value(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(
        self,
        *,
        value: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___Spec = Spec

class Status(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    @property
    def value(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(
        self,
        *,
        value: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___Status = Status



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import jfml.hosting_gateway.v1.build_upload_url_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetBuildVersioningUploadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> jfml.hosting_gateway.v1.build_upload_url_pb2.BuildUploadUrlParameters:
        """The params to define the url."""
    def __init__(
        self,
        *,
        params: jfml.hosting_gateway.v1.build_upload_url_pb2.BuildUploadUrlParameters | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___GetBuildVersioningUploadURLRequest = GetBuildVersioningUploadURLRequest

class GetBuildVersioningUploadURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPLOAD_URL_FIELD_NUMBER: builtins.int
    upload_url: builtins.str
    """Upload url intended for the upload"""
    def __init__(
        self,
        *,
        upload_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["upload_url", b"upload_url"]) -> None: ...

global___GetBuildVersioningUploadURLResponse = GetBuildVersioningUploadURLResponse



import grpc
from _qwak_proto.qwak.administration.authenticated_user.v1.authenticated_user_service_pb2 import (
    GetCloudCredentialsRequest,
    GetCloudCredentialsResponse,
    GetDetailsRequest,
    GetDetailsResponse,
)
from _qwak_proto.qwak.administration.authenticated_user.v1.authenticated_user_service_pb2_grpc import (
    AuthenticatedUserStub,
)
from dependency_injector.wiring import Provide
from qwak.exceptions import QwakException
from qwak.inner.di_configuration import QwakContainer


class AuthenticatedUserClient:
    """
    Used for interacting with Qwaks's Authenticated User service
    """

    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self._authenticated_user = AuthenticatedUserStub(grpc_channel)

    def get_details(self) -> GetDetailsResponse:
        request = GetDetailsRequest()
        try:
            return self._authenticated_user.GetDetails(request)
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to get authenticated user details, error is {e.details()}"
            )

    def get_cloud_credentials(self) -> GetCloudCredentialsResponse:
        request = GetCloudCredentialsRequest()
        try:
            return self._authenticated_user.GetCloudCredentials(request)
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to get cloud credentials, error is {e.details()}"
            )
